/* transfers.c generated by valac 0.38.8, the Vala compiler
 * generated from transfers.vala, do not modify */

/*
   Copyright (C) 2009-2013 Christian Dywan <christian@twotoasts.de>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   See the file COPYING for the full license text.
*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include "webkit/webkit.h"
#include "midori-core.h"
#include <float.h>
#include <math.h>
#include "katze/katze.h"
#include "midori/midori-stock.h"
#include <glib/gi18n-lib.h>
#include <gdk/gdk.h>
#include <gio/gio.h>
#include "midori/midori-browser.h"
#include <pango/pango.h>
#include "midori/midori-extension.h"
#include "midori/midori-app.h"
#include "midori/midori-view.h"
#include "midori/midori-panel.h"
#include "transfers.h"


#define TRANSFERS_TYPE_TRANSFER (transfers_transfer_get_type ())
#define TRANSFERS_TRANSFER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TRANSFERS_TYPE_TRANSFER, TransfersTransfer))
#define TRANSFERS_TRANSFER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TRANSFERS_TYPE_TRANSFER, TransfersTransferClass))
#define TRANSFERS_IS_TRANSFER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TRANSFERS_TYPE_TRANSFER))
#define TRANSFERS_IS_TRANSFER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TRANSFERS_TYPE_TRANSFER))
#define TRANSFERS_TRANSFER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TRANSFERS_TYPE_TRANSFER, TransfersTransferClass))

typedef struct _TransfersTransfer TransfersTransfer;
typedef struct _TransfersTransferClass TransfersTransferClass;
typedef struct _TransfersTransferPrivate TransfersTransferPrivate;
enum  {
	TRANSFERS_TRANSFER_0_PROPERTY,
	TRANSFERS_TRANSFER_ACTION_PROPERTY,
	TRANSFERS_TRANSFER_PROGRESS_PROPERTY,
	TRANSFERS_TRANSFER_SUCCEEDED_PROPERTY,
	TRANSFERS_TRANSFER_FINISHED_PROPERTY,
	TRANSFERS_TRANSFER_DESTINATION_PROPERTY,
	TRANSFERS_TRANSFER_NUM_PROPERTIES
};
static GParamSpec* transfers_transfer_properties[TRANSFERS_TRANSFER_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block1Data Block1Data;
#define _g_free0(var) (var = (g_free (var), NULL))
enum  {
	TRANSFERS_TRANSFER_CHANGED_SIGNAL,
	TRANSFERS_TRANSFER_REMOVE_SIGNAL,
	TRANSFERS_TRANSFER_REMOVED_SIGNAL,
	TRANSFERS_TRANSFER_NUM_SIGNALS
};
static guint transfers_transfer_signals[TRANSFERS_TRANSFER_NUM_SIGNALS] = {0};
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

#define TRANSFERS_TYPE_SIDEBAR (transfers_sidebar_get_type ())
#define TRANSFERS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TRANSFERS_TYPE_SIDEBAR, TransfersSidebar))
#define TRANSFERS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TRANSFERS_TYPE_SIDEBAR, TransfersSidebarClass))
#define TRANSFERS_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TRANSFERS_TYPE_SIDEBAR))
#define TRANSFERS_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TRANSFERS_TYPE_SIDEBAR))
#define TRANSFERS_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TRANSFERS_TYPE_SIDEBAR, TransfersSidebarClass))

typedef struct _TransfersSidebar TransfersSidebar;
typedef struct _TransfersSidebarClass TransfersSidebarClass;
typedef struct _TransfersSidebarPrivate TransfersSidebarPrivate;
enum  {
	TRANSFERS_SIDEBAR_0_PROPERTY,
	TRANSFERS_SIDEBAR_NUM_PROPERTIES
};
static GParamSpec* transfers_sidebar_properties[TRANSFERS_SIDEBAR_NUM_PROPERTIES];
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block2Data Block2Data;
typedef struct _Block3Data Block3Data;

#define TRANSFERS_TYPE_TRANSFER_BUTTON (transfers_transfer_button_get_type ())
#define TRANSFERS_TRANSFER_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TRANSFERS_TYPE_TRANSFER_BUTTON, TransfersTransferButton))
#define TRANSFERS_TRANSFER_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TRANSFERS_TYPE_TRANSFER_BUTTON, TransfersTransferButtonClass))
#define TRANSFERS_IS_TRANSFER_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TRANSFERS_TYPE_TRANSFER_BUTTON))
#define TRANSFERS_IS_TRANSFER_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TRANSFERS_TYPE_TRANSFER_BUTTON))
#define TRANSFERS_TRANSFER_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TRANSFERS_TYPE_TRANSFER_BUTTON, TransfersTransferButtonClass))

typedef struct _TransfersTransferButton TransfersTransferButton;
typedef struct _TransfersTransferButtonClass TransfersTransferButtonClass;
typedef struct _TransfersTransferButtonPrivate TransfersTransferButtonPrivate;
enum  {
	TRANSFERS_TRANSFER_BUTTON_0_PROPERTY,
	TRANSFERS_TRANSFER_BUTTON_NUM_PROPERTIES
};
static GParamSpec* transfers_transfer_button_properties[TRANSFERS_TRANSFER_BUTTON_NUM_PROPERTIES];

#define TRANSFERS_TYPE_TOOLBAR (transfers_toolbar_get_type ())
#define TRANSFERS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TRANSFERS_TYPE_TOOLBAR, TransfersToolbar))
#define TRANSFERS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TRANSFERS_TYPE_TOOLBAR, TransfersToolbarClass))
#define TRANSFERS_IS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TRANSFERS_TYPE_TOOLBAR))
#define TRANSFERS_IS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TRANSFERS_TYPE_TOOLBAR))
#define TRANSFERS_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TRANSFERS_TYPE_TOOLBAR, TransfersToolbarClass))

typedef struct _TransfersToolbar TransfersToolbar;
typedef struct _TransfersToolbarClass TransfersToolbarClass;
typedef struct _TransfersToolbarPrivate TransfersToolbarPrivate;
enum  {
	TRANSFERS_TOOLBAR_0_PROPERTY,
	TRANSFERS_TOOLBAR_NUM_PROPERTIES
};
static GParamSpec* transfers_toolbar_properties[TRANSFERS_TOOLBAR_NUM_PROPERTIES];

#define TRANSFERS_TYPE_MANAGER (transfers_manager_get_type ())
#define TRANSFERS_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TRANSFERS_TYPE_MANAGER, TransfersManager))
#define TRANSFERS_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TRANSFERS_TYPE_MANAGER, TransfersManagerClass))
#define TRANSFERS_IS_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TRANSFERS_TYPE_MANAGER))
#define TRANSFERS_IS_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TRANSFERS_TYPE_MANAGER))
#define TRANSFERS_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TRANSFERS_TYPE_MANAGER, TransfersManagerClass))

typedef struct _TransfersManager TransfersManager;
typedef struct _TransfersManagerClass TransfersManagerClass;
typedef struct _TransfersManagerPrivate TransfersManagerPrivate;
enum  {
	TRANSFERS_MANAGER_0_PROPERTY,
	TRANSFERS_MANAGER_NUM_PROPERTIES
};
static GParamSpec* transfers_manager_properties[TRANSFERS_MANAGER_NUM_PROPERTIES];
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define __g_list_free__g_free0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_free0_ (var), NULL)))

struct _TransfersTransfer {
	GObject parent_instance;
	TransfersTransferPrivate * priv;
	guint poll_source;
	WebKitDownload* download;
};

struct _TransfersTransferClass {
	GObjectClass parent_class;
	void (*changed) (TransfersTransfer* self);
};

struct _Block1Data {
	int _ref_count_;
	TransfersTransfer* self;
	WebKitDownload* download;
};

struct _TransfersSidebar {
	GtkVBox parent_instance;
	TransfersSidebarPrivate * priv;
};

struct _TransfersSidebarClass {
	GtkVBoxClass parent_class;
};

struct _TransfersSidebarPrivate {
	GtkToolbar* toolbar;
	GtkToolButton* clear;
	GtkListStore* store;
	GtkTreeView* treeview;
	KatzeArray* array;
};

struct _Block2Data {
	int _ref_count_;
	TransfersSidebar* self;
	TransfersTransfer* transfer;
};

struct _Block3Data {
	int _ref_count_;
	TransfersSidebar* self;
	TransfersTransfer* transfer;
};

struct _TransfersTransferButton {
	GtkToolItem parent_instance;
	TransfersTransferButtonPrivate * priv;
};

struct _TransfersTransferButtonClass {
	GtkToolItemClass parent_class;
};

struct _TransfersTransferButtonPrivate {
	TransfersTransfer* transfer;
	GtkProgressBar* progress;
	GtkImage* icon;
	GtkButton* button;
};

struct _TransfersToolbar {
	GtkToolbar parent_instance;
	TransfersToolbarPrivate * priv;
};

struct _TransfersToolbarClass {
	GtkToolbarClass parent_class;
};

struct _TransfersToolbarPrivate {
	KatzeArray* array;
	GtkToolButton* clear;
};

struct _TransfersManager {
	MidoriExtension parent_instance;
	TransfersManagerPrivate * priv;
	KatzeArray* array;
	GList* widgets;
	GList* notifications;
	guint notification_timeout;
};

struct _TransfersManagerClass {
	MidoriExtensionClass parent_class;
};


static gpointer transfers_transfer_parent_class = NULL;
static gpointer transfers_sidebar_parent_class = NULL;
static MidoriViewableIface * transfers_sidebar_midori_viewable_parent_iface = NULL;
static gpointer transfers_transfer_button_parent_class = NULL;
static gpointer transfers_toolbar_parent_class = NULL;
static gpointer transfers_manager_parent_class = NULL;

void gtk_widget_size_request (GtkWidget* widget, GtkRequisition* requisition);
void sokoke_widget_get_text_size (GtkWidget* widget, const gchar* sample, gint* width, gint* height);
GType transfers_transfer_get_type (void) G_GNUC_CONST;
TransfersTransfer* transfers_transfer_new (WebKitDownload* download);
TransfersTransfer* transfers_transfer_construct (GType object_type, WebKitDownload* download);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static gboolean __lambda4_ (TransfersTransfer* self);
static gboolean ___lambda4__gsource_func (gpointer self);
static void __lambda5_ (Block1Data* _data1_);
static void ___lambda5__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
gint transfers_transfer_get_action (TransfersTransfer* self);
gdouble transfers_transfer_get_progress (TransfersTransfer* self);
gboolean transfers_transfer_get_succeeded (TransfersTransfer* self);
gboolean transfers_transfer_get_finished (TransfersTransfer* self);
const gchar* transfers_transfer_get_destination (TransfersTransfer* self);
static void transfers_transfer_real_changed (TransfersTransfer* self);
static void transfers_transfer_finalize (GObject * obj);
static void _vala_transfers_transfer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
gboolean transfers_pending_transfers (KatzeArray* array);
GType transfers_sidebar_get_type (void) G_GNUC_CONST;
#define TRANSFERS_SIDEBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TRANSFERS_TYPE_SIDEBAR, TransfersSidebarPrivate))
static const gchar* transfers_sidebar_real_get_stock_id (MidoriViewable* base);
static const gchar* transfers_sidebar_real_get_label (MidoriViewable* base);
static GtkWidget* transfers_sidebar_real_get_toolbar (MidoriViewable* base);
static void transfers_sidebar_clear_clicked (TransfersSidebar* self);
static void _transfers_sidebar_clear_clicked_gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self);
TransfersSidebar* transfers_sidebar_new (KatzeArray* array);
TransfersSidebar* transfers_sidebar_construct (GType object_type, KatzeArray* array);
static gint transfers_sidebar_tree_sort_func (TransfersSidebar* self, GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b);
static gint _transfers_sidebar_tree_sort_func_gtk_tree_iter_compare_func (GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b, gpointer self);
static void transfers_sidebar_on_render_icon (TransfersSidebar* self, GtkCellLayout* column, GtkCellRenderer* renderer, GtkTreeModel* model, GtkTreeIter* iter);
static void _transfers_sidebar_on_render_icon_gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self);
static void transfers_sidebar_on_render_text (TransfersSidebar* self, GtkCellLayout* column, GtkCellRenderer* renderer, GtkTreeModel* model, GtkTreeIter* iter);
static void _transfers_sidebar_on_render_text_gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self);
static void transfers_sidebar_on_render_button (TransfersSidebar* self, GtkCellLayout* column, GtkCellRenderer* renderer, GtkTreeModel* model, GtkTreeIter* iter);
static void _transfers_sidebar_on_render_button_gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self);
static void transfers_sidebar_row_activated (TransfersSidebar* self, GtkTreePath* path, GtkTreeViewColumn* column);
static void _transfers_sidebar_row_activated_gtk_tree_view_row_activated (GtkTreeView* _sender, GtkTreePath* path, GtkTreeViewColumn* column, gpointer self);
static gboolean transfers_sidebar_button_released (TransfersSidebar* self, GdkEventButton* event);
static gboolean _transfers_sidebar_button_released_gtk_widget_button_release_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
static gboolean transfers_sidebar_menu_popup (TransfersSidebar* self);
static gboolean _transfers_sidebar_menu_popup_gtk_widget_popup_menu (GtkWidget* _sender, gpointer self);
static void transfers_sidebar_transfer_added (TransfersSidebar* self, GObject* item);
static void _transfers_sidebar_transfer_added_katze_array_add_item (KatzeArray* _sender, GObject* item, gpointer self);
static void transfers_sidebar_transfer_removed (TransfersSidebar* self, GObject* item);
static void _transfers_sidebar_transfer_removed_katze_array_remove_item (KatzeArray* _sender, GObject* item, gpointer self);
static gboolean transfers_sidebar_show_popup_menu (TransfersSidebar* self, GdkEventButton* event);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static void ___lambda6_ (Block2Data* _data2_);
static void ____lambda6__gtk_menu_item_activate (GtkMenuItem* _sender, gpointer self);
static void ___lambda7_ (Block2Data* _data2_);
static void ____lambda7__gtk_menu_item_activate (GtkMenuItem* _sender, gpointer self);
static void ___lambda8_ (Block2Data* _data2_);
static void ____lambda8__gtk_menu_item_activate (GtkMenuItem* _sender, gpointer self);
static void transfers_sidebar_transfer_changed (TransfersSidebar* self, GObject* item);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static void __lambda9_ (Block3Data* _data3_);
static void ___lambda9__transfers_transfer_changed (TransfersTransfer* _sender, gpointer self);
static void _transfers_sidebar_transfer_changed_transfers_transfer_changed (TransfersTransfer* _sender, gpointer self);
static void transfers_sidebar_finalize (GObject * obj);
GType transfers_transfer_button_get_type (void) G_GNUC_CONST;
#define TRANSFERS_TRANSFER_BUTTON_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TRANSFERS_TYPE_TRANSFER_BUTTON, TransfersTransferButtonPrivate))
TransfersTransferButton* transfers_transfer_button_new (TransfersTransfer* transfer);
TransfersTransferButton* transfers_transfer_button_construct (GType object_type, TransfersTransfer* transfer);
static void transfers_transfer_button_button_clicked (TransfersTransferButton* self);
static void _transfers_transfer_button_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void transfers_transfer_button_transfer_changed (TransfersTransferButton* self);
static void _transfers_transfer_button_transfer_changed_transfers_transfer_changed (TransfersTransfer* _sender, gpointer self);
static void transfers_transfer_button_transfer_removed (TransfersTransferButton* self);
static void _transfers_transfer_button_transfer_removed_transfers_transfer_removed (TransfersTransfer* _sender, gpointer self);
static void transfers_transfer_button_finalize (GObject * obj);
GType transfers_toolbar_get_type (void) G_GNUC_CONST;
#define TRANSFERS_TOOLBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TRANSFERS_TYPE_TOOLBAR, TransfersToolbarPrivate))
static void transfers_toolbar_clear_clicked (TransfersToolbar* self);
TransfersToolbar* transfers_toolbar_new (KatzeArray* array);
TransfersToolbar* transfers_toolbar_construct (GType object_type, KatzeArray* array);
static void _transfers_toolbar_clear_clicked_gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self);
static void transfers_toolbar_transfer_added (TransfersToolbar* self, GObject* item);
static void _transfers_toolbar_transfer_added_katze_array_add_item (KatzeArray* _sender, GObject* item, gpointer self);
static void transfers_toolbar_transfer_removed (TransfersToolbar* self, GObject* item);
static void _transfers_toolbar_transfer_removed_katze_array_remove_item (KatzeArray* _sender, GObject* item, gpointer self);
static void transfers_toolbar_finalize (GObject * obj);
GType transfers_manager_get_type (void) G_GNUC_CONST;
static void _g_object_unref0_ (gpointer var);
static inline void _g_list_free__g_object_unref0_ (GList* self);
static void _g_free0_ (gpointer var);
static inline void _g_list_free__g_free0_ (GList* self);
static void transfers_manager_download_added (TransfersManager* self, WebKitDownload* download);
static void transfers_manager_transfer_remove (TransfersManager* self, TransfersTransfer* transfer);
static void _transfers_manager_transfer_remove_transfers_transfer_remove (TransfersTransfer* _sender, gpointer self);
static void transfers_manager_transfer_changed (TransfersManager* self, TransfersTransfer* transfer);
static void _transfers_manager_transfer_changed_transfers_transfer_changed (TransfersTransfer* _sender, gpointer self);
static void transfers_manager_transfer_removed (TransfersManager* self, GObject* item);
static void _transfers_manager_transfer_removed_katze_array_remove_item (KatzeArray* _sender, GObject* item, gpointer self);
static gboolean transfers_manager_notification_timeout_triggered (TransfersManager* self);
static gboolean _transfers_manager_notification_timeout_triggered_gsource_func (gpointer self);
static gboolean transfers_manager_browser_closed (TransfersManager* self, GtkWidget* widget, GdkEvent* event);
static void transfers_manager_browser_added (TransfersManager* self, MidoriBrowser* browser);
static void _transfers_manager_download_added_midori_browser_add_download (MidoriBrowser* _sender, WebKitDownload* download, gpointer self);
static gboolean _transfers_manager_browser_closed_gtk_widget_delete_event (GtkWidget* _sender, GdkEvent* event, gpointer self);
static void transfers_manager_activated (TransfersManager* self, MidoriApp* app);
static void _transfers_manager_browser_added_midori_app_add_browser (MidoriApp* _sender, MidoriBrowser* browser, gpointer self);
static void transfers_manager_deactivated (TransfersManager* self);
TransfersManager* transfers_manager_new (void);
TransfersManager* transfers_manager_construct (GType object_type);
static void _transfers_manager_activated_midori_extension_activate (MidoriExtension* _sender, MidoriApp* app, gpointer self);
static void _transfers_manager_deactivated_midori_extension_deactivate (MidoriExtension* _sender, gpointer self);
static void transfers_manager_finalize (GObject * obj);


static gpointer _g_object_ref0 (gpointer self) {
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return self ? g_object_ref (self) : NULL;
#line 354 "transfers.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return _data1_;
#line 363 "transfers.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 372 "transfers.c"
		TransfersTransfer* self;
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		self = _data1_->self;
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (_data1_->download);
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (self);
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_slice_free (Block1Data, _data1_);
#line 382 "transfers.c"
	}
}


static gboolean __lambda4_ (TransfersTransfer* self) {
	gboolean result = FALSE;
#line 59 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_emit (self, transfers_transfer_signals[TRANSFERS_TRANSFER_CHANGED_SIGNAL], 0);
#line 60 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = TRUE;
#line 60 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 395 "transfers.c"
}


static gboolean ___lambda4__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda4_ ((TransfersTransfer*) self);
#line 58 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 404 "transfers.c"
}


static void __lambda5_ (Block1Data* _data1_) {
	TransfersTransfer* self;
	gboolean _tmp0_ = FALSE;
	WebKitDownload* _tmp1_;
	WebKitDownloadStatus _tmp2_;
	WebKitDownloadStatus _tmp3_;
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = _data1_->self;
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_emit (self, transfers_transfer_signals[TRANSFERS_TRANSFER_CHANGED_SIGNAL], 0);
#line 80 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = _data1_->download;
#line 80 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = webkit_download_get_status (_tmp1_);
#line 80 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = _tmp2_;
#line 80 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp3_ == WEBKIT_DOWNLOAD_STATUS_FINISHED) {
#line 80 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp0_ = TRUE;
#line 428 "transfers.c"
	} else {
		WebKitDownload* _tmp4_;
		WebKitDownloadStatus _tmp5_;
		WebKitDownloadStatus _tmp6_;
#line 80 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp4_ = _data1_->download;
#line 80 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp5_ = webkit_download_get_status (_tmp4_);
#line 80 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp6_ = _tmp5_;
#line 80 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp0_ = _tmp6_ == WEBKIT_DOWNLOAD_STATUS_ERROR;
#line 441 "transfers.c"
	}
#line 80 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp0_) {
#line 445 "transfers.c"
		guint _tmp7_;
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp7_ = self->poll_source;
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_source_remove (_tmp7_);
#line 82 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		self->poll_source = (guint) 0;
#line 453 "transfers.c"
	}
}


static void ___lambda5__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	__lambda5_ (self);
#line 461 "transfers.c"
}


TransfersTransfer* transfers_transfer_construct (GType object_type, WebKitDownload* download) {
	TransfersTransfer * self = NULL;
	Block1Data* _data1_;
	WebKitDownload* _tmp0_;
	WebKitDownload* _tmp1_;
	guint _tmp2_;
	WebKitDownload* _tmp3_;
	WebKitDownload* _tmp4_;
	WebKitDownload* _tmp5_;
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (download != NULL, NULL);
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_data1_->_ref_count_ = 1;
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = download;
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (_data1_->download);
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_data1_->download = _tmp1_;
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = (TransfersTransfer*) g_object_new (object_type, NULL);
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_data1_->self = g_object_ref (self);
#line 58 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) (1000 / 10), ___lambda4__gsource_func, g_object_ref (self), g_object_unref);
#line 58 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->poll_source = _tmp2_;
#line 62 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = _data1_->download;
#line 62 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 62 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->download);
#line 62 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->download = _tmp4_;
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp5_ = _data1_->download;
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_data ((GObject*) _tmp5_, "notify::status", (GCallback) ___lambda5__g_object_notify, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	block1_data_unref (_data1_);
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_data1_ = NULL;
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return self;
#line 514 "transfers.c"
}


TransfersTransfer* transfers_transfer_new (WebKitDownload* download) {
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return transfers_transfer_construct (TRANSFERS_TYPE_TRANSFER, download);
#line 521 "transfers.c"
}


gint transfers_transfer_get_action (TransfersTransfer* self) {
	gint result;
	WebKitDownload* _tmp0_;
	gint _tmp1_;
#line 33 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->download;
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = midori_download_get_type (_tmp0_);
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = _tmp1_;
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 539 "transfers.c"
}


gdouble transfers_transfer_get_progress (TransfersTransfer* self) {
	gdouble result;
	WebKitDownload* _tmp0_;
	gdouble _tmp1_;
#line 36 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (self != NULL, 0.0);
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->download;
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = midori_download_get_progress (_tmp0_);
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = _tmp1_;
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 557 "transfers.c"
}


gboolean transfers_transfer_get_succeeded (TransfersTransfer* self) {
	gboolean result;
	WebKitDownload* _tmp0_;
	WebKitDownloadStatus _tmp1_;
	WebKitDownloadStatus _tmp2_;
#line 46 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 47 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->download;
#line 47 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = webkit_download_get_status (_tmp0_);
#line 47 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = _tmp1_;
#line 47 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = _tmp2_ == WEBKIT_DOWNLOAD_STATUS_FINISHED;
#line 47 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 578 "transfers.c"
}


gboolean transfers_transfer_get_finished (TransfersTransfer* self) {
	gboolean result;
	WebKitDownload* _tmp0_;
	gboolean _tmp1_;
#line 49 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 50 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->download;
#line 50 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = midori_download_is_finished (_tmp0_);
#line 50 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = _tmp1_;
#line 50 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 596 "transfers.c"
}


const gchar* transfers_transfer_get_destination (TransfersTransfer* self) {
	const gchar* result;
	WebKitDownload* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
#line 52 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->download;
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = webkit_download_get_destination_uri (_tmp0_);
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = _tmp1_;
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = _tmp2_;
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 617 "transfers.c"
}


static void transfers_transfer_real_changed (TransfersTransfer* self) {
	gchar* tooltip = NULL;
	WebKitDownload* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->download;
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = midori_download_calculate_tooltip (_tmp0_);
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	tooltip = _tmp1_;
#line 28 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = g_strdup (tooltip);
#line 28 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_set_data_full ((GObject*) self, "tooltip", _tmp2_, g_free);
#line 25 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_free0 (tooltip);
#line 638 "transfers.c"
}


static void transfers_transfer_class_init (TransfersTransferClass * klass) {
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_transfer_parent_class = g_type_class_peek_parent (klass);
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	((TransfersTransferClass *) klass)->changed = transfers_transfer_real_changed;
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_transfers_transfer_get_property;
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	G_OBJECT_CLASS (klass)->finalize = transfers_transfer_finalize;
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRANSFERS_TRANSFER_ACTION_PROPERTY, transfers_transfer_properties[TRANSFERS_TRANSFER_ACTION_PROPERTY] = g_param_spec_int ("action", "action", "action", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRANSFERS_TRANSFER_PROGRESS_PROPERTY, transfers_transfer_properties[TRANSFERS_TRANSFER_PROGRESS_PROPERTY] = g_param_spec_double ("progress", "progress", "progress", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRANSFERS_TRANSFER_SUCCEEDED_PROPERTY, transfers_transfer_properties[TRANSFERS_TRANSFER_SUCCEEDED_PROPERTY] = g_param_spec_boolean ("succeeded", "succeeded", "succeeded", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRANSFERS_TRANSFER_FINISHED_PROPERTY, transfers_transfer_properties[TRANSFERS_TRANSFER_FINISHED_PROPERTY] = g_param_spec_boolean ("finished", "finished", "finished", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRANSFERS_TRANSFER_DESTINATION_PROPERTY, transfers_transfer_properties[TRANSFERS_TRANSFER_DESTINATION_PROPERTY] = g_param_spec_string ("destination", "destination", "destination", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_transfer_signals[TRANSFERS_TRANSFER_CHANGED_SIGNAL] = g_signal_new ("changed", TRANSFERS_TYPE_TRANSFER, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (TransfersTransferClass, changed), NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_transfer_signals[TRANSFERS_TRANSFER_REMOVE_SIGNAL] = g_signal_new ("remove", TRANSFERS_TYPE_TRANSFER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_transfer_signals[TRANSFERS_TRANSFER_REMOVED_SIGNAL] = g_signal_new ("removed", TRANSFERS_TYPE_TRANSFER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 667 "transfers.c"
}


static void transfers_transfer_instance_init (TransfersTransfer * self) {
#line 22 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->poll_source = (guint) 0;
#line 674 "transfers.c"
}


static void transfers_transfer_finalize (GObject * obj) {
	TransfersTransfer * self;
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TRANSFERS_TYPE_TRANSFER, TransfersTransfer);
#line 23 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->download);
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	G_OBJECT_CLASS (transfers_transfer_parent_class)->finalize (obj);
#line 686 "transfers.c"
}


GType transfers_transfer_get_type (void) {
	static volatile gsize transfers_transfer_type_id__volatile = 0;
	if (g_once_init_enter (&transfers_transfer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TransfersTransferClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) transfers_transfer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TransfersTransfer), 0, (GInstanceInitFunc) transfers_transfer_instance_init, NULL };
		GType transfers_transfer_type_id;
		transfers_transfer_type_id = g_type_register_static (G_TYPE_OBJECT, "TransfersTransfer", &g_define_type_info, 0);
		g_once_init_leave (&transfers_transfer_type_id__volatile, transfers_transfer_type_id);
	}
	return transfers_transfer_type_id__volatile;
}


static void _vala_transfers_transfer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	TransfersTransfer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TRANSFERS_TYPE_TRANSFER, TransfersTransfer);
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	switch (property_id) {
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		case TRANSFERS_TRANSFER_ACTION_PROPERTY:
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_value_set_int (value, transfers_transfer_get_action (self));
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		break;
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		case TRANSFERS_TRANSFER_PROGRESS_PROPERTY:
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_value_set_double (value, transfers_transfer_get_progress (self));
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		break;
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		case TRANSFERS_TRANSFER_SUCCEEDED_PROPERTY:
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_value_set_boolean (value, transfers_transfer_get_succeeded (self));
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		break;
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		case TRANSFERS_TRANSFER_FINISHED_PROPERTY:
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_value_set_boolean (value, transfers_transfer_get_finished (self));
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		break;
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		case TRANSFERS_TRANSFER_DESTINATION_PROPERTY:
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_value_set_string (value, transfers_transfer_get_destination (self));
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		break;
#line 737 "transfers.c"
		default:
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		break;
#line 743 "transfers.c"
	}
}


gboolean transfers_pending_transfers (KatzeArray* array) {
	gboolean result = FALSE;
	KatzeArray* _tmp0_;
	GList* _tmp1_;
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (array != NULL, FALSE);
#line 90 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = array;
#line 90 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = katze_array_get_items (_tmp0_);
#line 758 "transfers.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 90 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		item_collection = _tmp1_;
#line 90 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 766 "transfers.c"
			GObject* _tmp2_;
			GObject* item = NULL;
#line 90 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp2_ = _g_object_ref0 ((GObject*) ((KatzeItem*) item_it->data));
#line 90 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			item = _tmp2_;
#line 773 "transfers.c"
			{
				TransfersTransfer* transfer = NULL;
				GObject* _tmp3_;
				TransfersTransfer* _tmp4_;
				TransfersTransfer* _tmp5_;
				gboolean _tmp6_;
				gboolean _tmp7_;
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp3_ = item;
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, TRANSFERS_TYPE_TRANSFER) ? ((TransfersTransfer*) _tmp3_) : NULL);
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				transfer = _tmp4_;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp5_ = transfer;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp6_ = transfers_transfer_get_finished (_tmp5_);
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp7_ = _tmp6_;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				if (!_tmp7_) {
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					result = TRUE;
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					_g_object_unref0 (transfer);
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					_g_object_unref0 (item);
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					_g_list_free0 (item_collection);
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					return result;
#line 805 "transfers.c"
				}
#line 90 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_g_object_unref0 (transfer);
#line 90 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_g_object_unref0 (item);
#line 811 "transfers.c"
			}
		}
#line 90 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_list_free0 (item_collection);
#line 816 "transfers.c"
	}
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = FALSE;
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 822 "transfers.c"
}


static const gchar* transfers_sidebar_real_get_stock_id (MidoriViewable* base) {
	TransfersSidebar * self;
	const gchar* result = NULL;
#line 105 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = (TransfersSidebar*) base;
#line 106 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = MIDORI_STOCK_TRANSFER;
#line 106 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 835 "transfers.c"
}


static const gchar* transfers_sidebar_real_get_label (MidoriViewable* base) {
	TransfersSidebar * self;
	const gchar* result = NULL;
#line 109 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = (TransfersSidebar*) base;
#line 110 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = _ ("Transfers");
#line 110 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 848 "transfers.c"
}


static void _transfers_sidebar_clear_clicked_gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self) {
#line 125 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_sidebar_clear_clicked ((TransfersSidebar*) self);
#line 855 "transfers.c"
}


static GtkWidget* transfers_sidebar_real_get_toolbar (MidoriViewable* base) {
	TransfersSidebar * self;
	GtkWidget* result = NULL;
	GtkToolbar* _tmp0_;
	GtkToolbar* _tmp21_;
	GtkWidget* _tmp22_;
#line 113 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = (TransfersSidebar*) base;
#line 114 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->priv->toolbar;
#line 114 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp0_ == NULL) {
#line 871 "transfers.c"
		GtkToolbar* _tmp1_;
		GtkToolbar* _tmp2_;
		GtkToolbar* _tmp3_;
		GtkToolItem* _tmp4_;
		GtkToolItem* _tmp5_;
		GtkSeparatorToolItem* separator = NULL;
		GtkSeparatorToolItem* _tmp6_;
		GtkSeparatorToolItem* _tmp7_;
		GtkSeparatorToolItem* _tmp8_;
		GtkToolbar* _tmp9_;
		GtkSeparatorToolItem* _tmp10_;
		GtkToolButton* _tmp11_;
		GtkToolButton* _tmp12_;
		GtkToolButton* _tmp13_;
		GtkToolButton* _tmp14_;
		GtkToolButton* _tmp15_;
		KatzeArray* _tmp16_;
		gboolean _tmp17_;
		GtkToolbar* _tmp18_;
		GtkToolButton* _tmp19_;
		GtkToolbar* _tmp20_;
#line 115 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp1_ = (GtkToolbar*) gtk_toolbar_new ();
#line 115 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_object_ref_sink (_tmp1_);
#line 115 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (self->priv->toolbar);
#line 115 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		self->priv->toolbar = _tmp1_;
#line 116 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp2_ = self->priv->toolbar;
#line 116 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_toolbar_set_icon_size (_tmp2_, GTK_ICON_SIZE_BUTTON);
#line 117 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp3_ = self->priv->toolbar;
#line 117 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp4_ = gtk_tool_item_new ();
#line 117 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_object_ref_sink (_tmp4_);
#line 117 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp5_ = _tmp4_;
#line 117 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_toolbar_insert (_tmp3_, _tmp5_, -1);
#line 117 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (_tmp5_);
#line 118 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp6_ = (GtkSeparatorToolItem*) gtk_separator_tool_item_new ();
#line 118 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_object_ref_sink (_tmp6_);
#line 118 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		separator = _tmp6_;
#line 119 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp7_ = separator;
#line 119 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_separator_tool_item_set_draw (_tmp7_, FALSE);
#line 120 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp8_ = separator;
#line 120 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_tool_item_set_expand ((GtkToolItem*) _tmp8_, TRUE);
#line 121 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp9_ = self->priv->toolbar;
#line 121 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp10_ = separator;
#line 121 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_toolbar_insert (_tmp9_, (GtkToolItem*) _tmp10_, -1);
#line 122 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp11_ = (GtkToolButton*) gtk_tool_button_new_from_stock (GTK_STOCK_CLEAR);
#line 122 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_object_ref_sink (_tmp11_);
#line 122 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (self->priv->clear);
#line 122 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		self->priv->clear = _tmp11_;
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp12_ = self->priv->clear;
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_tool_button_set_label (_tmp12_, _ ("Clear All"));
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp13_ = self->priv->clear;
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_tool_item_set_is_important ((GtkToolItem*) _tmp13_, TRUE);
#line 125 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp14_ = self->priv->clear;
#line 125 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_signal_connect_object (_tmp14_, "clicked", (GCallback) _transfers_sidebar_clear_clicked_gtk_tool_button_clicked, self, 0);
#line 126 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp15_ = self->priv->clear;
#line 126 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp16_ = self->priv->array;
#line 126 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp17_ = katze_array_is_empty (_tmp16_);
#line 126 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _tmp15_, !_tmp17_);
#line 127 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp18_ = self->priv->toolbar;
#line 127 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp19_ = self->priv->clear;
#line 127 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_toolbar_insert (_tmp18_, (GtkToolItem*) _tmp19_, -1);
#line 128 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp20_ = self->priv->toolbar;
#line 128 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_widget_show_all ((GtkWidget*) _tmp20_);
#line 114 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (separator);
#line 977 "transfers.c"
	}
#line 130 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp21_ = self->priv->toolbar;
#line 130 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp22_ = _g_object_ref0 ((GtkWidget*) _tmp21_);
#line 130 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = _tmp22_;
#line 130 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 987 "transfers.c"
}


static void transfers_sidebar_clear_clicked (TransfersSidebar* self) {
	KatzeArray* _tmp0_;
	GList* _tmp1_;
#line 133 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->priv->array;
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = katze_array_get_items (_tmp0_);
#line 1000 "transfers.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		item_collection = _tmp1_;
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 1008 "transfers.c"
			GObject* _tmp2_;
			GObject* item = NULL;
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp2_ = _g_object_ref0 ((GObject*) ((KatzeItem*) item_it->data));
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			item = _tmp2_;
#line 1015 "transfers.c"
			{
				TransfersTransfer* transfer = NULL;
				GObject* _tmp3_;
				TransfersTransfer* _tmp4_;
				TransfersTransfer* _tmp5_;
				gboolean _tmp6_;
				gboolean _tmp7_;
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp3_ = item;
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, TRANSFERS_TYPE_TRANSFER) ? ((TransfersTransfer*) _tmp3_) : NULL);
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				transfer = _tmp4_;
#line 136 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp5_ = transfer;
#line 136 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp6_ = transfers_transfer_get_finished (_tmp5_);
#line 136 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp7_ = _tmp6_;
#line 136 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				if (_tmp7_) {
#line 1037 "transfers.c"
					TransfersTransfer* _tmp8_;
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					_tmp8_ = transfer;
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					g_signal_emit (_tmp8_, transfers_transfer_signals[TRANSFERS_TRANSFER_REMOVE_SIGNAL], 0);
#line 1043 "transfers.c"
				}
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_g_object_unref0 (transfer);
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_g_object_unref0 (item);
#line 1049 "transfers.c"
			}
		}
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_list_free0 (item_collection);
#line 1054 "transfers.c"
	}
}


static gint _transfers_sidebar_tree_sort_func_gtk_tree_iter_compare_func (GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b, gpointer self) {
	gint result;
	result = transfers_sidebar_tree_sort_func ((TransfersSidebar*) self, model, a, b);
#line 148 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 1064 "transfers.c"
}


static void _transfers_sidebar_on_render_icon_gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self) {
#line 153 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_sidebar_on_render_icon ((TransfersSidebar*) self, cell_layout, cell, tree_model, iter);
#line 1071 "transfers.c"
}


static void _transfers_sidebar_on_render_text_gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self) {
#line 161 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_sidebar_on_render_text ((TransfersSidebar*) self, cell_layout, cell, tree_model, iter);
#line 1078 "transfers.c"
}


static void _transfers_sidebar_on_render_button_gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self) {
#line 167 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_sidebar_on_render_button ((TransfersSidebar*) self, cell_layout, cell, tree_model, iter);
#line 1085 "transfers.c"
}


static void _transfers_sidebar_row_activated_gtk_tree_view_row_activated (GtkTreeView* _sender, GtkTreePath* path, GtkTreeViewColumn* column, gpointer self) {
#line 170 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_sidebar_row_activated ((TransfersSidebar*) self, path, column);
#line 1092 "transfers.c"
}


static gboolean _transfers_sidebar_button_released_gtk_widget_button_release_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = transfers_sidebar_button_released ((TransfersSidebar*) self, event);
#line 171 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 1101 "transfers.c"
}


static gboolean _transfers_sidebar_menu_popup_gtk_widget_popup_menu (GtkWidget* _sender, gpointer self) {
	gboolean result;
	result = transfers_sidebar_menu_popup ((TransfersSidebar*) self);
#line 172 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 1110 "transfers.c"
}


static void _transfers_sidebar_transfer_added_katze_array_add_item (KatzeArray* _sender, GObject* item, gpointer self) {
#line 177 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_sidebar_transfer_added ((TransfersSidebar*) self, item);
#line 1117 "transfers.c"
}


static void _transfers_sidebar_transfer_removed_katze_array_remove_item (KatzeArray* _sender, GObject* item, gpointer self) {
#line 178 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_sidebar_transfer_removed ((TransfersSidebar*) self, item);
#line 1124 "transfers.c"
}


TransfersSidebar* transfers_sidebar_construct (GType object_type, KatzeArray* array) {
	TransfersSidebar * self = NULL;
	GtkTreeViewColumn* column = NULL;
	GtkListStore* _tmp0_;
	GtkTreeView* _tmp1_;
	GtkTreeView* _tmp2_;
	GtkListStore* _tmp3_;
	GtkListStore* _tmp4_;
	GtkTreeViewColumn* _tmp5_;
	GtkCellRendererPixbuf* renderer_icon = NULL;
	GtkCellRendererPixbuf* _tmp6_;
	GtkTreeViewColumn* _tmp7_;
	GtkCellRendererPixbuf* _tmp8_;
	GtkTreeViewColumn* _tmp9_;
	GtkCellRendererPixbuf* _tmp10_;
	GtkTreeView* _tmp11_;
	GtkTreeViewColumn* _tmp12_;
	GtkTreeViewColumn* _tmp13_;
	GtkTreeViewColumn* _tmp14_;
	GtkCellRendererProgress* renderer_progress = NULL;
	GtkCellRendererProgress* _tmp15_;
	GtkTreeViewColumn* _tmp16_;
	GtkCellRendererProgress* _tmp17_;
	GtkTreeViewColumn* _tmp18_;
	GtkTreeViewColumn* _tmp19_;
	GtkCellRendererProgress* _tmp20_;
	GtkTreeView* _tmp21_;
	GtkTreeViewColumn* _tmp22_;
	GtkTreeViewColumn* _tmp23_;
	GtkCellRendererPixbuf* renderer_button = NULL;
	GtkCellRendererPixbuf* _tmp24_;
	GtkTreeViewColumn* _tmp25_;
	GtkCellRendererPixbuf* _tmp26_;
	GtkTreeViewColumn* _tmp27_;
	GtkCellRendererPixbuf* _tmp28_;
	GtkTreeView* _tmp29_;
	GtkTreeViewColumn* _tmp30_;
	GtkTreeView* _tmp31_;
	GtkTreeView* _tmp32_;
	GtkTreeView* _tmp33_;
	GtkTreeView* _tmp34_;
	GtkTreeView* _tmp35_;
	KatzeArray* _tmp36_;
	KatzeArray* _tmp37_;
	KatzeArray* _tmp38_;
	KatzeArray* _tmp39_;
	KatzeArray* _tmp40_;
	GList* _tmp41_;
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (array != NULL, NULL);
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = (TransfersSidebar*) g_object_new (object_type, NULL);
#line 144 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->priv->store;
#line 144 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = (GtkTreeView*) gtk_tree_view_new_with_model ((GtkTreeModel*) _tmp0_);
#line 144 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_ref_sink (_tmp1_);
#line 144 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->treeview);
#line 144 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->priv->treeview = _tmp1_;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = self->priv->treeview;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_tree_view_set_headers_visible (_tmp2_, FALSE);
#line 147 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = self->priv->store;
#line 147 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable*) _tmp3_, 0, GTK_SORT_ASCENDING);
#line 148 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = self->priv->store;
#line 148 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_tree_sortable_set_sort_func ((GtkTreeSortable*) _tmp4_, 0, _transfers_sidebar_tree_sort_func_gtk_tree_iter_compare_func, g_object_ref (self), g_object_unref);
#line 150 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp5_ = gtk_tree_view_column_new ();
#line 150 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_ref_sink (_tmp5_);
#line 150 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (column);
#line 150 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	column = _tmp5_;
#line 151 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp6_ = (GtkCellRendererPixbuf*) gtk_cell_renderer_pixbuf_new ();
#line 151 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_ref_sink (_tmp6_);
#line 151 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	renderer_icon = _tmp6_;
#line 152 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp7_ = column;
#line 152 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp8_ = renderer_icon;
#line 152 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_cell_layout_pack_start ((GtkCellLayout*) _tmp7_, (GtkCellRenderer*) _tmp8_, FALSE);
#line 153 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp9_ = column;
#line 153 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp10_ = renderer_icon;
#line 153 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_cell_layout_set_cell_data_func ((GtkCellLayout*) _tmp9_, (GtkCellRenderer*) _tmp10_, _transfers_sidebar_on_render_icon_gtk_cell_layout_data_func, g_object_ref (self), g_object_unref);
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp11_ = self->priv->treeview;
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp12_ = column;
#line 154 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_tree_view_append_column (_tmp11_, _tmp12_);
#line 156 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp13_ = gtk_tree_view_column_new ();
#line 156 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_ref_sink (_tmp13_);
#line 156 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (column);
#line 156 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	column = _tmp13_;
#line 157 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp14_ = column;
#line 157 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_tree_view_column_set_sizing (_tmp14_, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp15_ = (GtkCellRendererProgress*) gtk_cell_renderer_progress_new ();
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_ref_sink (_tmp15_);
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	renderer_progress = _tmp15_;
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp16_ = column;
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp17_ = renderer_progress;
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_cell_layout_pack_start ((GtkCellLayout*) _tmp16_, (GtkCellRenderer*) _tmp17_, TRUE);
#line 160 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp18_ = column;
#line 160 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_tree_view_column_set_expand (_tmp18_, TRUE);
#line 161 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp19_ = column;
#line 161 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp20_ = renderer_progress;
#line 161 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_cell_layout_set_cell_data_func ((GtkCellLayout*) _tmp19_, (GtkCellRenderer*) _tmp20_, _transfers_sidebar_on_render_text_gtk_cell_layout_data_func, g_object_ref (self), g_object_unref);
#line 162 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp21_ = self->priv->treeview;
#line 162 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp22_ = column;
#line 162 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_tree_view_append_column (_tmp21_, _tmp22_);
#line 164 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp23_ = gtk_tree_view_column_new ();
#line 164 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_ref_sink (_tmp23_);
#line 164 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (column);
#line 164 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	column = _tmp23_;
#line 165 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp24_ = (GtkCellRendererPixbuf*) gtk_cell_renderer_pixbuf_new ();
#line 165 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_ref_sink (_tmp24_);
#line 165 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	renderer_button = _tmp24_;
#line 166 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp25_ = column;
#line 166 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp26_ = renderer_button;
#line 166 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_cell_layout_pack_start ((GtkCellLayout*) _tmp25_, (GtkCellRenderer*) _tmp26_, FALSE);
#line 167 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp27_ = column;
#line 167 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp28_ = renderer_button;
#line 167 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_cell_layout_set_cell_data_func ((GtkCellLayout*) _tmp27_, (GtkCellRenderer*) _tmp28_, _transfers_sidebar_on_render_button_gtk_cell_layout_data_func, g_object_ref (self), g_object_unref);
#line 168 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp29_ = self->priv->treeview;
#line 168 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp30_ = column;
#line 168 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_tree_view_append_column (_tmp29_, _tmp30_);
#line 170 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp31_ = self->priv->treeview;
#line 170 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object (_tmp31_, "row-activated", (GCallback) _transfers_sidebar_row_activated_gtk_tree_view_row_activated, self, 0);
#line 171 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp32_ = self->priv->treeview;
#line 171 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object ((GtkWidget*) _tmp32_, "button-release-event", (GCallback) _transfers_sidebar_button_released_gtk_widget_button_release_event, self, 0);
#line 172 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp33_ = self->priv->treeview;
#line 172 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object ((GtkWidget*) _tmp33_, "popup-menu", (GCallback) _transfers_sidebar_menu_popup_gtk_widget_popup_menu, self, 0);
#line 173 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp34_ = self->priv->treeview;
#line 173 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_widget_show ((GtkWidget*) _tmp34_);
#line 174 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp35_ = self->priv->treeview;
#line 174 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_box_pack_start ((GtkBox*) self, (GtkWidget*) _tmp35_, TRUE, TRUE, (guint) 0);
#line 176 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp36_ = array;
#line 176 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp37_ = _g_object_ref0 (_tmp36_);
#line 176 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->array);
#line 176 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->priv->array = _tmp37_;
#line 177 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp38_ = array;
#line 177 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object (_tmp38_, "add-item", (GCallback) _transfers_sidebar_transfer_added_katze_array_add_item, self, 0);
#line 178 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp39_ = array;
#line 178 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object (_tmp39_, "remove-item", (GCallback) _transfers_sidebar_transfer_removed_katze_array_remove_item, self, G_CONNECT_AFTER);
#line 179 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp40_ = array;
#line 179 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp41_ = katze_array_get_items (_tmp40_);
#line 1346 "transfers.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 179 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		item_collection = _tmp41_;
#line 179 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 1354 "transfers.c"
			GObject* _tmp42_;
			GObject* item = NULL;
#line 179 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp42_ = _g_object_ref0 ((GObject*) ((KatzeItem*) item_it->data));
#line 179 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			item = _tmp42_;
#line 1361 "transfers.c"
			{
				GObject* _tmp43_;
#line 180 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp43_ = item;
#line 180 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				transfers_sidebar_transfer_added (self, _tmp43_);
#line 179 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_g_object_unref0 (item);
#line 1370 "transfers.c"
			}
		}
#line 179 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_list_free0 (item_collection);
#line 1375 "transfers.c"
	}
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (renderer_button);
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (renderer_progress);
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (renderer_icon);
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (column);
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return self;
#line 1387 "transfers.c"
}


TransfersSidebar* transfers_sidebar_new (KatzeArray* array) {
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return transfers_sidebar_construct (TRANSFERS_TYPE_SIDEBAR, array);
#line 1394 "transfers.c"
}


static void transfers_sidebar_row_activated (TransfersSidebar* self, GtkTreePath* path, GtkTreeViewColumn* column) {
	GtkTreeIter iter = {0};
	GtkListStore* _tmp0_;
	GtkTreePath* _tmp1_;
	GtkTreeIter _tmp2_ = {0};
	gboolean _tmp3_;
	GError * _inner_error_ = NULL;
#line 183 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 183 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (path != NULL);
#line 183 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (column != NULL);
#line 185 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->priv->store;
#line 185 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = path;
#line 185 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = gtk_tree_model_get_iter ((GtkTreeModel*) _tmp0_, &_tmp2_, _tmp1_);
#line 185 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	iter = _tmp2_;
#line 185 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp3_) {
#line 1421 "transfers.c"
		TransfersTransfer* transfer = NULL;
		GtkListStore* _tmp4_;
		GtkTreeIter _tmp5_;
#line 187 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp4_ = self->priv->store;
#line 187 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp5_ = iter;
#line 187 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_tree_model_get ((GtkTreeModel*) _tmp4_, &_tmp5_, 0, &transfer, -1);
#line 1431 "transfers.c"
		{
			gboolean _tmp6_ = FALSE;
			TransfersTransfer* _tmp7_;
			WebKitDownload* _tmp8_;
			GtkTreeView* _tmp9_;
			gboolean _tmp10_;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp7_ = transfer;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp8_ = _tmp7_->download;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp9_ = self->priv->treeview;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp10_ = midori_download_action_clear (_tmp8_, (GtkWidget*) _tmp9_, &_inner_error_);
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp6_ = _tmp10_;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1450 "transfers.c"
				goto __catch0_g_error;
			}
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			if (_tmp6_) {
#line 1455 "transfers.c"
				TransfersTransfer* _tmp11_;
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp11_ = transfer;
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				g_signal_emit (_tmp11_, transfers_transfer_signals[TRANSFERS_TRANSFER_REMOVE_SIGNAL], 0);
#line 1461 "transfers.c"
			}
		}
		goto __finally0;
		__catch0_g_error:
		{
			GError* _error_ = NULL;
			GError* _tmp12_;
			const gchar* _tmp13_;
#line 189 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_error_ = _inner_error_;
#line 189 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_inner_error_ = NULL;
#line 194 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp12_ = _error_;
#line 194 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp13_ = _tmp12_->message;
#line 194 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			g_warning (_ ("Failed to open download: %s"), _tmp13_);
#line 189 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_g_error_free0 (_error_);
#line 1482 "transfers.c"
		}
		__finally0:
#line 189 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 189 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_g_object_unref0 (transfer);
#line 189 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 189 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			g_clear_error (&_inner_error_);
#line 189 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			return;
#line 1495 "transfers.c"
		}
#line 185 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (transfer);
#line 1499 "transfers.c"
	}
}


static gboolean transfers_sidebar_button_released (TransfersSidebar* self, GdkEventButton* event) {
	gboolean result = FALSE;
	GdkEventButton _tmp0_;
	guint _tmp1_;
#line 199 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 199 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 200 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = *event;
#line 200 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = _tmp0_.button;
#line 200 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp1_ == ((guint) 3)) {
#line 1518 "transfers.c"
		GdkEventButton _tmp2_;
		gboolean _tmp3_;
#line 201 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp2_ = *event;
#line 201 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp3_ = transfers_sidebar_show_popup_menu (self, &_tmp2_);
#line 201 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		result = _tmp3_;
#line 201 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		return result;
#line 1529 "transfers.c"
	}
#line 202 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = FALSE;
#line 202 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 1535 "transfers.c"
}


static gboolean transfers_sidebar_menu_popup (TransfersSidebar* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 205 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 206 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = transfers_sidebar_show_popup_menu (self, NULL);
#line 206 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = _tmp0_;
#line 206 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 1550 "transfers.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 211 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 211 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return _data2_;
#line 1559 "transfers.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 211 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 1568 "transfers.c"
		TransfersSidebar* self;
#line 211 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		self = _data2_->self;
#line 211 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (_data2_->transfer);
#line 211 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (self);
#line 211 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_slice_free (Block2Data, _data2_);
#line 1578 "transfers.c"
	}
}


static void ___lambda6_ (Block2Data* _data2_) {
	TransfersSidebar* self;
	GError * _inner_error_ = NULL;
#line 217 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = _data2_->self;
#line 1588 "transfers.c"
	{
		TransfersTransfer* _tmp0_;
		WebKitDownload* _tmp1_;
		GtkTreeView* _tmp2_;
#line 219 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp0_ = _data2_->transfer;
#line 219 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp1_ = _tmp0_->download;
#line 219 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp2_ = self->priv->treeview;
#line 219 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		midori_download_open (_tmp1_, (GtkWidget*) _tmp2_, &_inner_error_);
#line 219 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1603 "transfers.c"
			goto __catch1_g_error;
		}
	}
	goto __finally1;
	__catch1_g_error:
	{
		GError* error_open = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
#line 218 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		error_open = _inner_error_;
#line 218 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_inner_error_ = NULL;
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp3_ = error_open;
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp4_ = _tmp3_->message;
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_warning (_ ("Failed to open download: %s"), _tmp4_);
#line 218 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_error_free0 (error_open);
#line 1625 "transfers.c"
	}
	__finally1:
#line 218 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 218 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 218 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_clear_error (&_inner_error_);
#line 218 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		return;
#line 1636 "transfers.c"
	}
}


static void ____lambda6__gtk_menu_item_activate (GtkMenuItem* _sender, gpointer self) {
#line 217 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	___lambda6_ (self);
#line 1644 "transfers.c"
}


static void ___lambda7_ (Block2Data* _data2_) {
	TransfersSidebar* self;
	GFile* folder = NULL;
	TransfersTransfer* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	GFile* _tmp3_;
	MidoriBrowser* _tmp4_;
	GtkWidget* _tmp5_;
	GtkWidget* _tmp6_;
	GFile* _tmp7_;
	GFile* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gboolean _tmp11_ = FALSE;
#line 228 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = _data2_->self;
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = _data2_->transfer;
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = transfers_transfer_get_destination (_tmp0_);
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = _tmp1_;
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = g_file_new_for_uri (_tmp2_);
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	folder = _tmp3_;
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = midori_browser_get_for_widget ((GtkWidget*) self);
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp5_ = midori_browser_get_tab (_tmp4_);
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp6_ = _tmp5_;
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp7_ = g_file_get_parent (folder);
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp8_ = _tmp7_;
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp9_ = g_file_get_uri (_tmp8_);
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp10_ = _tmp9_;
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, MIDORI_TYPE_TAB) ? ((MidoriTab*) _tmp6_) : NULL, "open-uri", _tmp10_, &_tmp11_);
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_free0 (_tmp10_);
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (_tmp8_);
#line 228 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (folder);
#line 1697 "transfers.c"
}


static void ____lambda7__gtk_menu_item_activate (GtkMenuItem* _sender, gpointer self) {
#line 228 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	___lambda7_ (self);
#line 1704 "transfers.c"
}


static void ___lambda8_ (Block2Data* _data2_) {
	TransfersSidebar* self;
	gchar* uri = NULL;
	TransfersTransfer* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	GtkClipboard* _tmp4_;
	GtkClipboard* _tmp5_;
#line 234 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = _data2_->self;
#line 235 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = _data2_->transfer;
#line 235 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = transfers_transfer_get_destination (_tmp0_);
#line 235 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = _tmp1_;
#line 235 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 235 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	uri = _tmp3_;
#line 236 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = gtk_widget_get_clipboard ((GtkWidget*) self, GDK_SELECTION_PRIMARY);
#line 236 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_clipboard_set_text (_tmp4_, uri, -1);
#line 237 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp5_ = gtk_widget_get_clipboard ((GtkWidget*) self, GDK_SELECTION_CLIPBOARD);
#line 237 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_clipboard_set_text (_tmp5_, uri, -1);
#line 234 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_free0 (uri);
#line 1739 "transfers.c"
}


static void ____lambda8__gtk_menu_item_activate (GtkMenuItem* _sender, gpointer self) {
#line 234 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	___lambda8_ (self);
#line 1746 "transfers.c"
}


static gboolean transfers_sidebar_show_popup_menu (TransfersSidebar* self, GdkEventButton* event) {
	gboolean result = FALSE;
	GtkTreeIter iter = {0};
	GtkTreeView* _tmp0_;
	GtkTreeSelection* _tmp1_;
	GtkTreeIter _tmp2_ = {0};
	gboolean _tmp3_;
#line 209 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 211 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->priv->treeview;
#line 211 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = gtk_tree_view_get_selection (_tmp0_);
#line 211 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = gtk_tree_selection_get_selected (_tmp1_, NULL, &_tmp2_);
#line 211 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	iter = _tmp2_;
#line 211 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp3_) {
#line 1769 "transfers.c"
		Block2Data* _data2_;
		GtkListStore* _tmp4_;
		GtkTreeIter _tmp5_;
		GtkMenu* menu = NULL;
		GtkMenu* _tmp6_;
		GtkImageMenuItem* menuitem = NULL;
		GtkImageMenuItem* _tmp7_;
		GtkImageMenuItem* _tmp8_;
		GtkImageMenuItem* _tmp9_;
		TransfersTransfer* _tmp10_;
		gboolean _tmp11_;
		gboolean _tmp12_;
		GtkMenu* _tmp13_;
		GtkImageMenuItem* _tmp14_;
		GtkImageMenuItem* _tmp15_;
		GtkImageMenuItem* _tmp16_;
		GtkImage* _tmp17_;
		GtkImage* _tmp18_;
		GtkImageMenuItem* _tmp19_;
		GtkMenu* _tmp20_;
		GtkImageMenuItem* _tmp21_;
		GtkImageMenuItem* _tmp22_;
		GtkImageMenuItem* _tmp23_;
		GtkImageMenuItem* _tmp24_;
		GtkImage* _tmp25_;
		GtkImage* _tmp26_;
		GtkMenu* _tmp27_;
		GtkImageMenuItem* _tmp28_;
		GtkMenu* _tmp29_;
		GtkTreeView* _tmp30_;
		GtkMenu* _tmp31_;
#line 211 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_data2_ = g_slice_new0 (Block2Data);
#line 211 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_data2_->_ref_count_ = 1;
#line 211 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_data2_->self = g_object_ref (self);
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp4_ = self->priv->store;
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp5_ = iter;
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_tree_model_get ((GtkTreeModel*) _tmp4_, &_tmp5_, 0, &_data2_->transfer, -1);
#line 215 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp6_ = (GtkMenu*) gtk_menu_new ();
#line 215 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_object_ref_sink (_tmp6_);
#line 215 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		menu = _tmp6_;
#line 216 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp7_ = (GtkImageMenuItem*) gtk_image_menu_item_new_from_stock (GTK_STOCK_OPEN, NULL);
#line 216 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_object_ref_sink (_tmp7_);
#line 216 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		menuitem = _tmp7_;
#line 217 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp8_ = menuitem;
#line 217 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_signal_connect_data ((GtkMenuItem*) _tmp8_, "activate", (GCallback) ____lambda6__gtk_menu_item_activate, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 224 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp9_ = menuitem;
#line 224 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp10_ = _data2_->transfer;
#line 224 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp11_ = transfers_transfer_get_succeeded (_tmp10_);
#line 224 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp12_ = _tmp11_;
#line 224 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _tmp9_, _tmp12_);
#line 225 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp13_ = menu;
#line 225 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp14_ = menuitem;
#line 225 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_menu_shell_append ((GtkMenuShell*) _tmp13_, (GtkWidget*) ((GtkMenuItem*) _tmp14_));
#line 226 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp15_ = (GtkImageMenuItem*) gtk_image_menu_item_new_with_mnemonic (_ ("Open Destination _Folder"));
#line 226 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_object_ref_sink (_tmp15_);
#line 226 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (menuitem);
#line 226 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		menuitem = _tmp15_;
#line 227 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp16_ = menuitem;
#line 227 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp17_ = (GtkImage*) gtk_image_new_from_stock (GTK_STOCK_DIRECTORY, GTK_ICON_SIZE_MENU);
#line 227 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_object_ref_sink (_tmp17_);
#line 227 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp18_ = _tmp17_;
#line 227 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_image_menu_item_set_image (_tmp16_, (GtkWidget*) _tmp18_);
#line 227 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (_tmp18_);
#line 228 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp19_ = menuitem;
#line 228 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_signal_connect_data ((GtkMenuItem*) _tmp19_, "activate", (GCallback) ____lambda7__gtk_menu_item_activate, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 232 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp20_ = menu;
#line 232 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp21_ = menuitem;
#line 232 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_menu_shell_append ((GtkMenuShell*) _tmp20_, (GtkWidget*) ((GtkMenuItem*) _tmp21_));
#line 233 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp22_ = (GtkImageMenuItem*) gtk_image_menu_item_new_with_mnemonic (_ ("Copy Link Loc_ation"));
#line 233 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_object_ref_sink (_tmp22_);
#line 233 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (menuitem);
#line 233 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		menuitem = _tmp22_;
#line 234 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp23_ = menuitem;
#line 234 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_signal_connect_data ((GtkMenuItem*) _tmp23_, "activate", (GCallback) ____lambda8__gtk_menu_item_activate, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 239 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp24_ = menuitem;
#line 239 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp25_ = (GtkImage*) gtk_image_new_from_stock (GTK_STOCK_COPY, GTK_ICON_SIZE_MENU);
#line 239 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_object_ref_sink (_tmp25_);
#line 239 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp26_ = _tmp25_;
#line 239 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_image_menu_item_set_image (_tmp24_, (GtkWidget*) _tmp26_);
#line 239 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (_tmp26_);
#line 240 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp27_ = menu;
#line 240 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp28_ = menuitem;
#line 240 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_menu_shell_append ((GtkMenuShell*) _tmp27_, (GtkWidget*) ((GtkMenuItem*) _tmp28_));
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp29_ = menu;
#line 241 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_widget_show_all ((GtkWidget*) _tmp29_);
#line 242 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp30_ = self->priv->treeview;
#line 242 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp31_ = menu;
#line 242 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		katze_widget_popup ((GtkWidget*) _tmp30_, _tmp31_, NULL, KATZE_MENU_POSITION_CURSOR);
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		result = TRUE;
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (menuitem);
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (menu);
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		block2_data_unref (_data2_);
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_data2_ = NULL;
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		return result;
#line 1927 "transfers.c"
	}
#line 246 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = FALSE;
#line 246 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 1933 "transfers.c"
}


static gint transfers_sidebar_tree_sort_func (TransfersSidebar* self, GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b) {
	gint result = 0;
	TransfersTransfer* transfer1 = NULL;
	TransfersTransfer* transfer2 = NULL;
	GtkTreeModel* _tmp0_;
	GtkTreeIter _tmp1_;
	GtkTreeModel* _tmp2_;
	GtkTreeIter _tmp3_;
	gint _tmp4_ = 0;
	TransfersTransfer* _tmp5_;
	gboolean _tmp6_;
	gboolean _tmp7_;
	gint _tmp8_ = 0;
	TransfersTransfer* _tmp9_;
	gboolean _tmp10_;
	gboolean _tmp11_;
#line 249 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 249 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (model != NULL, 0);
#line 249 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (a != NULL, 0);
#line 249 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (b != NULL, 0);
#line 251 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = model;
#line 251 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = *a;
#line 251 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, 0, &transfer1, -1);
#line 252 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = model;
#line 252 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = *b;
#line 252 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_tree_model_get (_tmp2_, &_tmp3_, 0, &transfer2, -1);
#line 253 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp5_ = transfer1;
#line 253 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp6_ = transfers_transfer_get_finished (_tmp5_);
#line 253 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp7_ = _tmp6_;
#line 253 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp7_) {
#line 253 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp4_ = 1;
#line 1983 "transfers.c"
	} else {
#line 253 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp4_ = 0;
#line 1987 "transfers.c"
	}
#line 253 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp9_ = transfer2;
#line 253 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp10_ = transfers_transfer_get_finished (_tmp9_);
#line 253 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp11_ = _tmp10_;
#line 253 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp11_) {
#line 253 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp8_ = 1;
#line 1999 "transfers.c"
	} else {
#line 253 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp8_ = 0;
#line 2003 "transfers.c"
	}
#line 253 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = _tmp4_ - _tmp8_;
#line 253 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (transfer2);
#line 253 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (transfer1);
#line 253 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 2013 "transfers.c"
}


static void transfers_sidebar_transfer_changed (TransfersSidebar* self, GObject* item) {
	GtkTreeView* _tmp0_;
#line 256 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 256 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (item != NULL);
#line 257 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->priv->treeview;
#line 257 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_widget_queue_draw ((GtkWidget*) _tmp0_);
#line 2027 "transfers.c"
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 260 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 260 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return _data3_;
#line 2036 "transfers.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 260 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 2045 "transfers.c"
		TransfersSidebar* self;
#line 260 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		self = _data3_->self;
#line 260 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (_data3_->transfer);
#line 260 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (self);
#line 260 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_slice_free (Block3Data, _data3_);
#line 2055 "transfers.c"
	}
}


static void __lambda9_ (Block3Data* _data3_) {
	TransfersSidebar* self;
#line 265 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = _data3_->self;
#line 265 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_sidebar_transfer_changed (self, (GObject*) _data3_->transfer);
#line 2066 "transfers.c"
}


static void ___lambda9__transfers_transfer_changed (TransfersTransfer* _sender, gpointer self) {
#line 265 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	__lambda9_ (self);
#line 2073 "transfers.c"
}


static void transfers_sidebar_transfer_added (TransfersSidebar* self, GObject* item) {
	Block3Data* _data3_;
	GObject* _tmp0_;
	TransfersTransfer* _tmp1_;
	GtkTreeIter iter = {0};
	GtkListStore* _tmp2_;
	GtkTreeIter _tmp3_ = {0};
	GtkListStore* _tmp4_;
	GtkTreeIter _tmp5_;
	GtkToolButton* _tmp6_;
#line 260 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 260 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (item != NULL);
#line 260 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 260 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_data3_->_ref_count_ = 1;
#line 260 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_data3_->self = g_object_ref (self);
#line 261 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = item;
#line 261 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TRANSFERS_TYPE_TRANSFER) ? ((TransfersTransfer*) _tmp0_) : NULL);
#line 261 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_data3_->transfer = _tmp1_;
#line 263 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = self->priv->store;
#line 263 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_list_store_append (_tmp2_, &_tmp3_);
#line 263 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	iter = _tmp3_;
#line 264 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = self->priv->store;
#line 264 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp5_ = iter;
#line 264 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_list_store_set (_tmp4_, &_tmp5_, 0, _data3_->transfer, -1);
#line 265 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_data (_data3_->transfer, "changed", (GCallback) ___lambda9__transfers_transfer_changed, block3_data_ref (_data3_), (GClosureNotify) block3_data_unref, 0);
#line 266 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp6_ = self->priv->clear;
#line 266 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp6_, TRUE);
#line 260 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	block3_data_unref (_data3_);
#line 260 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_data3_ = NULL;
#line 2125 "transfers.c"
}


static void _transfers_sidebar_transfer_changed_transfers_transfer_changed (TransfersTransfer* _sender, gpointer self) {
#line 271 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_sidebar_transfer_changed ((TransfersSidebar*) self, _sender);
#line 2132 "transfers.c"
}


static void transfers_sidebar_transfer_removed (TransfersSidebar* self, GObject* item) {
	TransfersTransfer* transfer = NULL;
	GObject* _tmp0_;
	TransfersTransfer* _tmp1_;
	TransfersTransfer* _tmp2_;
	guint _tmp3_;
	GtkTreeIter iter = {0};
	GtkListStore* _tmp4_;
	GtkTreeIter _tmp5_ = {0};
	gboolean _tmp6_;
	KatzeArray* _tmp15_;
	gboolean _tmp16_;
#line 269 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 269 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (item != NULL);
#line 270 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = item;
#line 270 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TRANSFERS_TYPE_TRANSFER) ? ((TransfersTransfer*) _tmp0_) : NULL);
#line 270 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfer = _tmp1_;
#line 271 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = transfer;
#line 271 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_parse_name ("changed", TRANSFERS_TYPE_TRANSFER, &_tmp3_, NULL, FALSE);
#line 271 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _transfers_sidebar_transfer_changed_transfers_transfer_changed, self);
#line 273 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = self->priv->store;
#line 273 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp6_ = gtk_tree_model_iter_children ((GtkTreeModel*) _tmp4_, &_tmp5_, NULL);
#line 273 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	iter = _tmp5_;
#line 273 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp6_) {
#line 2172 "transfers.c"
		{
			gboolean _tmp7_ = FALSE;
#line 274 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp7_ = TRUE;
#line 274 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			while (TRUE) {
#line 2179 "transfers.c"
				TransfersTransfer* found = NULL;
				GtkListStore* _tmp10_;
				GtkTreeIter _tmp11_;
				TransfersTransfer* _tmp12_;
				TransfersTransfer* _tmp13_;
#line 274 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				if (!_tmp7_) {
#line 2187 "transfers.c"
					GtkListStore* _tmp8_;
					gboolean _tmp9_;
#line 281 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					_tmp8_ = self->priv->store;
#line 281 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					_tmp9_ = gtk_tree_model_iter_next ((GtkTreeModel*) _tmp8_, &iter);
#line 281 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					if (!_tmp9_) {
#line 281 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
						break;
#line 2198 "transfers.c"
					}
				}
#line 274 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp7_ = FALSE;
#line 276 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp10_ = self->priv->store;
#line 276 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp11_ = iter;
#line 276 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				gtk_tree_model_get ((GtkTreeModel*) _tmp10_, &_tmp11_, 0, &found, -1);
#line 277 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp12_ = transfer;
#line 277 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp13_ = found;
#line 277 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				if (_tmp12_ == _tmp13_) {
#line 2215 "transfers.c"
					GtkListStore* _tmp14_;
#line 278 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					_tmp14_ = self->priv->store;
#line 278 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					gtk_list_store_remove (_tmp14_, &iter);
#line 279 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					_g_object_unref0 (found);
#line 279 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					break;
#line 2225 "transfers.c"
				}
#line 274 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_g_object_unref0 (found);
#line 2229 "transfers.c"
			}
		}
	}
#line 283 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp15_ = self->priv->array;
#line 283 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp16_ = katze_array_is_empty (_tmp15_);
#line 283 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp16_) {
#line 2239 "transfers.c"
		GtkToolButton* _tmp17_;
#line 284 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp17_ = self->priv->clear;
#line 284 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _tmp17_, FALSE);
#line 2245 "transfers.c"
	}
#line 269 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (transfer);
#line 2249 "transfers.c"
}


static void transfers_sidebar_on_render_icon (TransfersSidebar* self, GtkCellLayout* column, GtkCellRenderer* renderer, GtkTreeModel* model, GtkTreeIter* iter) {
	TransfersTransfer* transfer = NULL;
	GtkTreeModel* _tmp0_;
	GtkTreeIter _tmp1_;
	gchar* content_type = NULL;
	WebKitDownload* _tmp2_;
	gchar* _tmp3_;
	GThemedIcon* icon = NULL;
	GIcon* _tmp4_;
	GThemedIcon* _tmp5_;
	GtkCellRenderer* _tmp6_;
#line 287 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 287 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (column != NULL);
#line 287 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (renderer != NULL);
#line 287 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (model != NULL);
#line 287 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (iter != NULL);
#line 291 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = model;
#line 291 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = *iter;
#line 291 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, 0, &transfer, -1);
#line 292 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = transfer->download;
#line 292 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = midori_download_get_content_type (_tmp2_, NULL);
#line 292 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	content_type = _tmp3_;
#line 293 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = g_content_type_get_icon (content_type);
#line 293 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp5_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, g_themed_icon_get_type ()) ? ((GThemedIcon*) _tmp4_) : NULL;
#line 293 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp5_ == NULL) {
#line 293 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (_tmp4_);
#line 2294 "transfers.c"
	}
#line 293 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	icon = _tmp5_;
#line 294 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_themed_icon_append_name (icon, "text-html");
#line 295 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp6_ = renderer;
#line 295 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_set ((GObject*) _tmp6_, "gicon", icon, "stock-size", GTK_ICON_SIZE_DND, "xpad", 1, "ypad", 12, NULL);
#line 287 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (icon);
#line 287 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_free0 (content_type);
#line 287 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (transfer);
#line 2310 "transfers.c"
}


static void transfers_sidebar_on_render_text (TransfersSidebar* self, GtkCellLayout* column, GtkCellRenderer* renderer, GtkTreeModel* model, GtkTreeIter* iter) {
	TransfersTransfer* transfer = NULL;
	GtkTreeModel* _tmp0_;
	GtkTreeIter _tmp1_;
	const gchar* _tmp2_ = NULL;
	TransfersTransfer* _tmp3_;
	gconstpointer _tmp4_;
	GtkCellRenderer* _tmp5_;
	TransfersTransfer* _tmp6_;
	gdouble _tmp7_;
	gdouble _tmp8_;
#line 300 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 300 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (column != NULL);
#line 300 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (renderer != NULL);
#line 300 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (model != NULL);
#line 300 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (iter != NULL);
#line 304 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = model;
#line 304 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = *iter;
#line 304 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, 0, &transfer, -1);
#line 305 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = transfer;
#line 305 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = g_object_get_data ((GObject*) _tmp3_, "tooltip");
#line 305 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = (const gchar*) _tmp4_;
#line 305 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp2_ == NULL) {
#line 305 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp2_ = "";
#line 2351 "transfers.c"
	}
#line 305 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp5_ = renderer;
#line 305 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp6_ = transfer;
#line 305 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp7_ = transfers_transfer_get_progress (_tmp6_);
#line 305 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp8_ = _tmp7_;
#line 305 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_set ((GObject*) _tmp5_, "text", _tmp2_, "value", (gint) (_tmp8_ * 100), NULL);
#line 300 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (transfer);
#line 2365 "transfers.c"
}


static void transfers_sidebar_on_render_button (TransfersSidebar* self, GtkCellLayout* column, GtkCellRenderer* renderer, GtkTreeModel* model, GtkTreeIter* iter) {
	TransfersTransfer* transfer = NULL;
	GtkTreeModel* _tmp0_;
	GtkTreeIter _tmp1_;
	gchar* stock_id = NULL;
	WebKitDownload* _tmp2_;
	gchar* _tmp3_;
	GtkCellRenderer* _tmp4_;
#line 309 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 309 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (column != NULL);
#line 309 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (renderer != NULL);
#line 309 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (model != NULL);
#line 309 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (iter != NULL);
#line 313 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = model;
#line 313 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = *iter;
#line 313 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, 0, &transfer, -1);
#line 314 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = transfer->download;
#line 314 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = midori_download_action_stock_id (_tmp2_);
#line 314 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	stock_id = _tmp3_;
#line 315 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = renderer;
#line 315 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_set ((GObject*) _tmp4_, "stock-id", stock_id, "stock-size", GTK_ICON_SIZE_MENU, NULL);
#line 309 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_free0 (stock_id);
#line 309 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (transfer);
#line 2407 "transfers.c"
}


static void transfers_sidebar_class_init (TransfersSidebarClass * klass) {
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_sidebar_parent_class = g_type_class_peek_parent (klass);
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_type_class_add_private (klass, sizeof (TransfersSidebarPrivate));
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	G_OBJECT_CLASS (klass)->finalize = transfers_sidebar_finalize;
#line 2418 "transfers.c"
}


static void transfers_sidebar_midori_viewable_interface_init (MidoriViewableIface * iface) {
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_sidebar_midori_viewable_parent_iface = g_type_interface_peek_parent (iface);
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	iface->get_stock_id = (const gchar* (*) (MidoriViewable *)) transfers_sidebar_real_get_stock_id;
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	iface->get_label = (const gchar* (*) (MidoriViewable *)) transfers_sidebar_real_get_label;
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	iface->get_toolbar = (GtkWidget* (*) (MidoriViewable *)) transfers_sidebar_real_get_toolbar;
#line 2431 "transfers.c"
}


static void transfers_sidebar_instance_init (TransfersSidebar * self) {
	GtkListStore* _tmp0_;
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->priv = TRANSFERS_SIDEBAR_GET_PRIVATE (self);
#line 99 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->priv->toolbar = NULL;
#line 101 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = gtk_list_store_new (1, TRANSFERS_TYPE_TRANSFER);
#line 101 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->priv->store = _tmp0_;
#line 2445 "transfers.c"
}


static void transfers_sidebar_finalize (GObject * obj) {
	TransfersSidebar * self;
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TRANSFERS_TYPE_SIDEBAR, TransfersSidebar);
#line 99 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->toolbar);
#line 100 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->clear);
#line 101 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->store);
#line 102 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->treeview);
#line 103 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->array);
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	G_OBJECT_CLASS (transfers_sidebar_parent_class)->finalize (obj);
#line 2465 "transfers.c"
}


GType transfers_sidebar_get_type (void) {
	static volatile gsize transfers_sidebar_type_id__volatile = 0;
	if (g_once_init_enter (&transfers_sidebar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TransfersSidebarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) transfers_sidebar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TransfersSidebar), 0, (GInstanceInitFunc) transfers_sidebar_instance_init, NULL };
		static const GInterfaceInfo midori_viewable_info = { (GInterfaceInitFunc) transfers_sidebar_midori_viewable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType transfers_sidebar_type_id;
		transfers_sidebar_type_id = g_type_register_static (GTK_TYPE_VBOX, "TransfersSidebar", &g_define_type_info, 0);
		g_type_add_interface_static (transfers_sidebar_type_id, MIDORI_TYPE_VIEWABLE, &midori_viewable_info);
		g_once_init_leave (&transfers_sidebar_type_id__volatile, transfers_sidebar_type_id);
	}
	return transfers_sidebar_type_id__volatile;
}


static void _transfers_transfer_button_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 346 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_transfer_button_button_clicked ((TransfersTransferButton*) self);
#line 2486 "transfers.c"
}


static void _transfers_transfer_button_transfer_changed_transfers_transfer_changed (TransfersTransfer* _sender, gpointer self) {
#line 353 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_transfer_button_transfer_changed ((TransfersTransferButton*) self);
#line 2493 "transfers.c"
}


static void _transfers_transfer_button_transfer_removed_transfers_transfer_removed (TransfersTransfer* _sender, gpointer self) {
#line 355 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_transfer_button_transfer_removed ((TransfersTransferButton*) self);
#line 2500 "transfers.c"
}


TransfersTransferButton* transfers_transfer_button_construct (GType object_type, TransfersTransfer* transfer) {
	TransfersTransferButton * self = NULL;
	TransfersTransfer* _tmp0_;
	TransfersTransfer* _tmp1_;
	GtkHBox* box = NULL;
	GtkHBox* _tmp2_;
	GtkProgressBar* _tmp3_;
	GtkProgressBar* _tmp4_;
	gchar* filename = NULL;
	TransfersTransfer* _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	gchar* _tmp8_;
	GtkProgressBar* _tmp9_;
	gint width = 0;
	GtkProgressBar* _tmp10_;
	gint _tmp11_ = 0;
	GtkProgressBar* _tmp12_;
	GtkProgressBar* _tmp13_;
	GtkImage* _tmp14_;
	GtkButton* _tmp15_;
	GtkButton* _tmp16_;
	GtkButton* _tmp17_;
	GtkButton* _tmp18_;
	GtkButton* _tmp19_;
	GtkImage* _tmp20_;
	GtkButton* _tmp21_;
	TransfersTransfer* _tmp22_;
	TransfersTransfer* _tmp23_;
#line 326 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (transfer != NULL, NULL);
#line 326 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = (TransfersTransferButton*) g_object_new (object_type, NULL);
#line 327 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = transfer;
#line 327 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 327 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->transfer);
#line 327 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->priv->transfer = _tmp1_;
#line 329 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = (GtkHBox*) gtk_hbox_new (FALSE, 0);
#line 329 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_ref_sink (_tmp2_);
#line 329 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	box = _tmp2_;
#line 330 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = (GtkProgressBar*) gtk_progress_bar_new ();
#line 330 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_ref_sink (_tmp3_);
#line 330 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->progress);
#line 330 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->priv->progress = _tmp3_;
#line 334 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = self->priv->progress;
#line 334 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_progress_bar_set_ellipsize (_tmp4_, PANGO_ELLIPSIZE_MIDDLE);
#line 335 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp5_ = transfer;
#line 335 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp6_ = transfers_transfer_get_destination (_tmp5_);
#line 335 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp7_ = _tmp6_;
#line 335 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp8_ = midori_download_get_basename_for_display (_tmp7_);
#line 335 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	filename = _tmp8_;
#line 336 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp9_ = self->priv->progress;
#line 336 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_progress_bar_set_text (_tmp9_, filename);
#line 338 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp10_ = self->priv->progress;
#line 338 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	sokoke_widget_get_text_size ((GtkWidget*) _tmp10_, "M", &_tmp11_, NULL);
#line 338 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	width = _tmp11_;
#line 339 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp12_ = self->priv->progress;
#line 339 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_widget_set_size_request ((GtkWidget*) _tmp12_, width * 10, 1);
#line 340 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp13_ = self->priv->progress;
#line 340 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_box_pack_start ((GtkBox*) box, (GtkWidget*) _tmp13_, FALSE, FALSE, (guint) 0);
#line 342 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp14_ = (GtkImage*) gtk_image_new ();
#line 342 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_ref_sink (_tmp14_);
#line 342 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->icon);
#line 342 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->priv->icon = _tmp14_;
#line 343 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp15_ = (GtkButton*) gtk_button_new ();
#line 343 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_ref_sink (_tmp15_);
#line 343 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->button);
#line 343 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->priv->button = _tmp15_;
#line 344 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp16_ = self->priv->button;
#line 344 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_button_set_relief (_tmp16_, GTK_RELIEF_NONE);
#line 345 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp17_ = self->priv->button;
#line 345 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_button_set_focus_on_click (_tmp17_, FALSE);
#line 346 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp18_ = self->priv->button;
#line 346 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object (_tmp18_, "clicked", (GCallback) _transfers_transfer_button_button_clicked_gtk_button_clicked, self, 0);
#line 347 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp19_ = self->priv->button;
#line 347 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp20_ = self->priv->icon;
#line 347 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_container_add ((GtkContainer*) _tmp19_, (GtkWidget*) _tmp20_);
#line 348 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp21_ = self->priv->button;
#line 348 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_box_pack_start ((GtkBox*) box, (GtkWidget*) _tmp21_, FALSE, FALSE, (guint) 0);
#line 350 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) box);
#line 351 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 353 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp22_ = transfer;
#line 353 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object (_tmp22_, "changed", (GCallback) _transfers_transfer_button_transfer_changed_transfers_transfer_changed, self, 0);
#line 354 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_transfer_button_transfer_changed (self);
#line 355 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp23_ = transfer;
#line 355 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object (_tmp23_, "removed", (GCallback) _transfers_transfer_button_transfer_removed_transfers_transfer_removed, self, 0);
#line 326 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_free0 (filename);
#line 326 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (box);
#line 326 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return self;
#line 2649 "transfers.c"
}


TransfersTransferButton* transfers_transfer_button_new (TransfersTransfer* transfer) {
#line 326 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return transfers_transfer_button_construct (TRANSFERS_TYPE_TRANSFER_BUTTON, transfer);
#line 2656 "transfers.c"
}


static void transfers_transfer_button_button_clicked (TransfersTransferButton* self) {
	GError * _inner_error_ = NULL;
#line 358 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 2664 "transfers.c"
	{
		gboolean _tmp0_ = FALSE;
		TransfersTransfer* _tmp1_;
		WebKitDownload* _tmp2_;
		GtkButton* _tmp3_;
		gboolean _tmp4_;
#line 360 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp1_ = self->priv->transfer;
#line 360 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp2_ = _tmp1_->download;
#line 360 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp3_ = self->priv->button;
#line 360 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp4_ = midori_download_action_clear (_tmp2_, (GtkWidget*) _tmp3_, &_inner_error_);
#line 360 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp0_ = _tmp4_;
#line 360 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2683 "transfers.c"
			goto __catch2_g_error;
		}
#line 360 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		if (_tmp0_) {
#line 2688 "transfers.c"
			TransfersTransfer* _tmp5_;
#line 361 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp5_ = self->priv->transfer;
#line 361 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			g_signal_emit (_tmp5_, transfers_transfer_signals[TRANSFERS_TRANSFER_REMOVE_SIGNAL], 0);
#line 2694 "transfers.c"
		}
	}
	goto __finally2;
	__catch2_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp6_;
		const gchar* _tmp7_;
#line 359 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_error_ = _inner_error_;
#line 359 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_inner_error_ = NULL;
#line 364 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp6_ = _error_;
#line 364 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp7_ = _tmp6_->message;
#line 364 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_warning (_ ("Failed to open download: %s"), _tmp7_);
#line 359 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_error_free0 (_error_);
#line 2715 "transfers.c"
	}
	__finally2:
#line 359 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 359 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 359 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_clear_error (&_inner_error_);
#line 359 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		return;
#line 2726 "transfers.c"
	}
}


static void transfers_transfer_button_transfer_changed (TransfersTransferButton* self) {
	GtkProgressBar* _tmp0_;
	TransfersTransfer* _tmp1_;
	WebKitDownload* _tmp2_;
	gdouble _tmp3_;
	const gchar* _tmp4_ = NULL;
	TransfersTransfer* _tmp5_;
	gconstpointer _tmp6_;
	GtkProgressBar* _tmp7_;
	gchar* stock_id = NULL;
	TransfersTransfer* _tmp8_;
	WebKitDownload* _tmp9_;
	gchar* _tmp10_;
	GtkImage* _tmp11_;
#line 368 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 369 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->priv->progress;
#line 369 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = self->priv->transfer;
#line 369 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = _tmp1_->download;
#line 369 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = midori_download_get_progress (_tmp2_);
#line 369 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_progress_bar_set_fraction (_tmp0_, _tmp3_);
#line 370 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp5_ = self->priv->transfer;
#line 370 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp6_ = g_object_get_data ((GObject*) _tmp5_, "tooltip");
#line 370 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = (const gchar*) _tmp6_;
#line 370 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp4_ == NULL) {
#line 370 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp4_ = "";
#line 2767 "transfers.c"
	}
#line 370 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp7_ = self->priv->progress;
#line 370 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp7_, _tmp4_);
#line 371 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp8_ = self->priv->transfer;
#line 371 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp9_ = _tmp8_->download;
#line 371 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp10_ = midori_download_action_stock_id (_tmp9_);
#line 371 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	stock_id = _tmp10_;
#line 372 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp11_ = self->priv->icon;
#line 372 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_image_set_from_stock (_tmp11_, stock_id, GTK_ICON_SIZE_MENU);
#line 368 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_free0 (stock_id);
#line 2787 "transfers.c"
}


static void transfers_transfer_button_transfer_removed (TransfersTransferButton* self) {
#line 375 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 376 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_object_destroy ((GtkObject*) self);
#line 2796 "transfers.c"
}


static void transfers_transfer_button_class_init (TransfersTransferButtonClass * klass) {
#line 320 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_transfer_button_parent_class = g_type_class_peek_parent (klass);
#line 320 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_type_class_add_private (klass, sizeof (TransfersTransferButtonPrivate));
#line 320 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	G_OBJECT_CLASS (klass)->finalize = transfers_transfer_button_finalize;
#line 2807 "transfers.c"
}


static void transfers_transfer_button_instance_init (TransfersTransferButton * self) {
#line 320 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->priv = TRANSFERS_TRANSFER_BUTTON_GET_PRIVATE (self);
#line 2814 "transfers.c"
}


static void transfers_transfer_button_finalize (GObject * obj) {
	TransfersTransferButton * self;
#line 320 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TRANSFERS_TYPE_TRANSFER_BUTTON, TransfersTransferButton);
#line 321 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->transfer);
#line 322 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->progress);
#line 323 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->icon);
#line 324 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->button);
#line 320 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	G_OBJECT_CLASS (transfers_transfer_button_parent_class)->finalize (obj);
#line 2832 "transfers.c"
}


GType transfers_transfer_button_get_type (void) {
	static volatile gsize transfers_transfer_button_type_id__volatile = 0;
	if (g_once_init_enter (&transfers_transfer_button_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TransfersTransferButtonClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) transfers_transfer_button_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TransfersTransferButton), 0, (GInstanceInitFunc) transfers_transfer_button_instance_init, NULL };
		GType transfers_transfer_button_type_id;
		transfers_transfer_button_type_id = g_type_register_static (GTK_TYPE_TOOL_ITEM, "TransfersTransferButton", &g_define_type_info, 0);
		g_once_init_leave (&transfers_transfer_button_type_id__volatile, transfers_transfer_button_type_id);
	}
	return transfers_transfer_button_type_id__volatile;
}


static void transfers_toolbar_clear_clicked (TransfersToolbar* self) {
	KatzeArray* _tmp0_;
	GList* _tmp1_;
#line 384 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 385 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->priv->array;
#line 385 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = katze_array_get_items (_tmp0_);
#line 2857 "transfers.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 385 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		item_collection = _tmp1_;
#line 385 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 2865 "transfers.c"
			GObject* _tmp2_;
			GObject* item = NULL;
#line 385 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp2_ = _g_object_ref0 ((GObject*) ((KatzeItem*) item_it->data));
#line 385 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			item = _tmp2_;
#line 2872 "transfers.c"
			{
				TransfersTransfer* transfer = NULL;
				GObject* _tmp3_;
				TransfersTransfer* _tmp4_;
				TransfersTransfer* _tmp5_;
				gboolean _tmp6_;
				gboolean _tmp7_;
#line 386 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp3_ = item;
#line 386 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, TRANSFERS_TYPE_TRANSFER) ? ((TransfersTransfer*) _tmp3_) : NULL);
#line 386 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				transfer = _tmp4_;
#line 387 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp5_ = transfer;
#line 387 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp6_ = transfers_transfer_get_finished (_tmp5_);
#line 387 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp7_ = _tmp6_;
#line 387 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				if (_tmp7_) {
#line 2894 "transfers.c"
					KatzeArray* _tmp8_;
					GObject* _tmp9_;
#line 388 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					_tmp8_ = self->priv->array;
#line 388 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					_tmp9_ = item;
#line 388 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					g_signal_emit_by_name (_tmp8_, "remove-item", _tmp9_);
#line 2903 "transfers.c"
				}
#line 385 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_g_object_unref0 (transfer);
#line 385 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_g_object_unref0 (item);
#line 2909 "transfers.c"
			}
		}
#line 385 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_list_free0 (item_collection);
#line 2914 "transfers.c"
	}
}


static void _transfers_toolbar_clear_clicked_gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self) {
#line 400 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_toolbar_clear_clicked ((TransfersToolbar*) self);
#line 2922 "transfers.c"
}


static void _transfers_toolbar_transfer_added_katze_array_add_item (KatzeArray* _sender, GObject* item, gpointer self) {
#line 407 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_toolbar_transfer_added ((TransfersToolbar*) self, item);
#line 2929 "transfers.c"
}


static void _transfers_toolbar_transfer_removed_katze_array_remove_item (KatzeArray* _sender, GObject* item, gpointer self) {
#line 408 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_toolbar_transfer_removed ((TransfersToolbar*) self, item);
#line 2936 "transfers.c"
}


TransfersToolbar* transfers_toolbar_construct (GType object_type, KatzeArray* array) {
	TransfersToolbar * self = NULL;
	GtkToolButton* _tmp0_;
	GtkToolButton* _tmp1_;
	GtkToolButton* _tmp2_;
	GtkToolButton* _tmp3_;
	GtkToolButton* _tmp4_;
	KatzeArray* _tmp5_;
	gboolean _tmp6_;
	GtkToolButton* _tmp7_;
	GtkToolButton* _tmp8_;
	GtkToolButton* _tmp9_;
	KatzeArray* _tmp10_;
	KatzeArray* _tmp11_;
	KatzeArray* _tmp12_;
	KatzeArray* _tmp13_;
	KatzeArray* _tmp14_;
	GList* _tmp15_;
#line 392 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (array != NULL, NULL);
#line 392 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = (TransfersToolbar*) g_object_new (object_type, NULL);
#line 393 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_toolbar_set_icon_size ((GtkToolbar*) self, GTK_ICON_SIZE_BUTTON);
#line 394 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_toolbar_set_style ((GtkToolbar*) self, GTK_TOOLBAR_BOTH_HORIZ);
#line 395 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_toolbar_set_show_arrow ((GtkToolbar*) self, FALSE);
#line 397 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = (GtkToolButton*) gtk_tool_button_new_from_stock (GTK_STOCK_CLEAR);
#line 397 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_ref_sink (_tmp0_);
#line 397 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->clear);
#line 397 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->priv->clear = _tmp0_;
#line 398 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = self->priv->clear;
#line 398 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_tool_button_set_label (_tmp1_, _ ("Clear All"));
#line 399 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = self->priv->clear;
#line 399 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_tool_item_set_is_important ((GtkToolItem*) _tmp2_, TRUE);
#line 400 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = self->priv->clear;
#line 400 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object (_tmp3_, "clicked", (GCallback) _transfers_toolbar_clear_clicked_gtk_tool_button_clicked, self, 0);
#line 401 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = self->priv->clear;
#line 401 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp5_ = array;
#line 401 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp6_ = katze_array_is_empty (_tmp5_);
#line 401 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp4_, !_tmp6_);
#line 402 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp7_ = self->priv->clear;
#line 402 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_toolbar_insert ((GtkToolbar*) self, (GtkToolItem*) _tmp7_, -1);
#line 403 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp8_ = self->priv->clear;
#line 403 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_widget_show ((GtkWidget*) _tmp8_);
#line 404 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp9_ = self->priv->clear;
#line 404 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp9_, FALSE);
#line 406 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp10_ = array;
#line 406 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp11_ = _g_object_ref0 (_tmp10_);
#line 406 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->array);
#line 406 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->priv->array = _tmp11_;
#line 407 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp12_ = array;
#line 407 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object (_tmp12_, "add-item", (GCallback) _transfers_toolbar_transfer_added_katze_array_add_item, self, 0);
#line 408 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp13_ = array;
#line 408 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object (_tmp13_, "remove-item", (GCallback) _transfers_toolbar_transfer_removed_katze_array_remove_item, self, G_CONNECT_AFTER);
#line 409 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp14_ = array;
#line 409 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp15_ = katze_array_get_items (_tmp14_);
#line 3028 "transfers.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 409 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		item_collection = _tmp15_;
#line 409 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 3036 "transfers.c"
			GObject* _tmp16_;
			GObject* item = NULL;
#line 409 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp16_ = _g_object_ref0 ((GObject*) ((KatzeItem*) item_it->data));
#line 409 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			item = _tmp16_;
#line 3043 "transfers.c"
			{
				GObject* _tmp17_;
#line 410 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp17_ = item;
#line 410 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				transfers_toolbar_transfer_added (self, _tmp17_);
#line 409 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_g_object_unref0 (item);
#line 3052 "transfers.c"
			}
		}
#line 409 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_list_free0 (item_collection);
#line 3057 "transfers.c"
	}
#line 392 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return self;
#line 3061 "transfers.c"
}


TransfersToolbar* transfers_toolbar_new (KatzeArray* array) {
#line 392 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return transfers_toolbar_construct (TRANSFERS_TYPE_TOOLBAR, array);
#line 3068 "transfers.c"
}


static void transfers_toolbar_transfer_added (TransfersToolbar* self, GObject* item) {
	TransfersTransfer* transfer = NULL;
	GObject* _tmp0_;
	TransfersTransfer* _tmp1_;
	TransfersTransfer* _tmp2_;
	TransfersTransferButton* _tmp3_;
	TransfersTransferButton* _tmp4_;
	GtkToolButton* _tmp5_;
	GtkRequisition req = {0};
	GtkContainer* _tmp6_;
	GtkContainer* _tmp7_;
	GtkRequisition _tmp8_ = {0};
	gint reqwidth = 0;
	GtkRequisition _tmp9_;
	gint _tmp10_;
	gint winwidth = 0;
	GtkWidget* _tmp11_;
	gint _tmp12_ = 0;
	gint _tmp13_;
	gint _tmp14_;
#line 413 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 413 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (item != NULL);
#line 414 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = item;
#line 414 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TRANSFERS_TYPE_TRANSFER) ? ((TransfersTransfer*) _tmp0_) : NULL);
#line 414 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfer = _tmp1_;
#line 416 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = transfer;
#line 416 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = transfers_transfer_button_new (_tmp2_);
#line 416 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_ref_sink (_tmp3_);
#line 416 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = _tmp3_;
#line 416 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_toolbar_insert ((GtkToolbar*) self, (GtkToolItem*) _tmp4_, 0);
#line 416 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (_tmp4_);
#line 417 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp5_ = self->priv->clear;
#line 417 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp5_, TRUE);
#line 418 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_widget_show ((GtkWidget*) self);
#line 421 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp6_ = gtk_widget_get_parent ((GtkWidget*) self);
#line 421 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp7_ = _tmp6_;
#line 421 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_widget_size_request ((GtkWidget*) _tmp7_, &_tmp8_);
#line 421 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	req = _tmp8_;
#line 422 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp9_ = req;
#line 422 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp10_ = _tmp9_.width;
#line 422 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	reqwidth = _tmp10_;
#line 424 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp11_ = gtk_widget_get_toplevel ((GtkWidget*) self);
#line 424 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_window_get_size (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, GTK_TYPE_WINDOW) ? ((GtkWindow*) _tmp11_) : NULL, &_tmp12_, NULL);
#line 424 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	winwidth = _tmp12_;
#line 425 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp13_ = reqwidth;
#line 425 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp14_ = winwidth;
#line 425 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp13_ > _tmp14_) {
#line 426 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		transfers_toolbar_clear_clicked (self);
#line 3148 "transfers.c"
	}
#line 413 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (transfer);
#line 3152 "transfers.c"
}


static void transfers_toolbar_transfer_removed (TransfersToolbar* self, GObject* item) {
	GtkToolButton* _tmp0_;
	KatzeArray* _tmp1_;
	gboolean _tmp2_;
	KatzeArray* _tmp3_;
	gboolean _tmp4_;
#line 429 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 429 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (item != NULL);
#line 430 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->priv->clear;
#line 430 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = self->priv->array;
#line 430 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = transfers_pending_transfers (_tmp1_);
#line 430 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, _tmp2_);
#line 431 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = self->priv->array;
#line 431 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = katze_array_is_empty (_tmp3_);
#line 431 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp4_) {
#line 432 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_widget_hide ((GtkWidget*) self);
#line 3182 "transfers.c"
	}
}


static void transfers_toolbar_class_init (TransfersToolbarClass * klass) {
#line 380 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_toolbar_parent_class = g_type_class_peek_parent (klass);
#line 380 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_type_class_add_private (klass, sizeof (TransfersToolbarPrivate));
#line 380 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	G_OBJECT_CLASS (klass)->finalize = transfers_toolbar_finalize;
#line 3194 "transfers.c"
}


static void transfers_toolbar_instance_init (TransfersToolbar * self) {
#line 380 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->priv = TRANSFERS_TOOLBAR_GET_PRIVATE (self);
#line 3201 "transfers.c"
}


static void transfers_toolbar_finalize (GObject * obj) {
	TransfersToolbar * self;
#line 380 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TRANSFERS_TYPE_TOOLBAR, TransfersToolbar);
#line 381 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->array);
#line 382 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->priv->clear);
#line 380 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	G_OBJECT_CLASS (transfers_toolbar_parent_class)->finalize (obj);
#line 3215 "transfers.c"
}


GType transfers_toolbar_get_type (void) {
	static volatile gsize transfers_toolbar_type_id__volatile = 0;
	if (g_once_init_enter (&transfers_toolbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TransfersToolbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) transfers_toolbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TransfersToolbar), 0, (GInstanceInitFunc) transfers_toolbar_instance_init, NULL };
		GType transfers_toolbar_type_id;
		transfers_toolbar_type_id = g_type_register_static (GTK_TYPE_TOOLBAR, "TransfersToolbar", &g_define_type_info, 0);
		g_once_init_leave (&transfers_toolbar_type_id__volatile, transfers_toolbar_type_id);
	}
	return transfers_toolbar_type_id__volatile;
}


static void _g_object_unref0_ (gpointer var) {
#line 438 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 3234 "transfers.c"
}


static inline void _g_list_free__g_object_unref0_ (GList* self) {
#line 438 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_list_free_full (self, (GDestroyNotify) _g_object_unref0_);
#line 3241 "transfers.c"
}


static void _g_free0_ (gpointer var) {
#line 439 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	var = (g_free (var), NULL);
#line 3248 "transfers.c"
}


static inline void _g_list_free__g_free0_ (GList* self) {
#line 439 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_list_free_full (self, (GDestroyNotify) _g_free0_);
#line 3255 "transfers.c"
}


static void _transfers_manager_transfer_remove_transfers_transfer_remove (TransfersTransfer* _sender, gpointer self) {
#line 444 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_manager_transfer_remove ((TransfersManager*) self, _sender);
#line 3262 "transfers.c"
}


static void _transfers_manager_transfer_changed_transfers_transfer_changed (TransfersTransfer* _sender, gpointer self) {
#line 445 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_manager_transfer_changed ((TransfersManager*) self, _sender);
#line 3269 "transfers.c"
}


static void _transfers_manager_transfer_removed_katze_array_remove_item (KatzeArray* _sender, GObject* item, gpointer self) {
#line 446 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_manager_transfer_removed ((TransfersManager*) self, item);
#line 3276 "transfers.c"
}


static void transfers_manager_download_added (TransfersManager* self, WebKitDownload* download) {
	TransfersTransfer* transfer = NULL;
	WebKitDownload* _tmp0_;
	TransfersTransfer* _tmp1_;
	KatzeArray* _tmp2_;
	KatzeArray* _tmp3_;
#line 442 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 442 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (download != NULL);
#line 443 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = download;
#line 443 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = transfers_transfer_new (_tmp0_);
#line 443 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfer = _tmp1_;
#line 444 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object (transfer, "remove", (GCallback) _transfers_manager_transfer_remove_transfers_transfer_remove, self, 0);
#line 445 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object (transfer, "changed", (GCallback) _transfers_manager_transfer_changed_transfers_transfer_changed, self, 0);
#line 446 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = self->array;
#line 446 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object (_tmp2_, "remove-item", (GCallback) _transfers_manager_transfer_removed_katze_array_remove_item, self, 0);
#line 447 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = self->array;
#line 447 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_emit_by_name (_tmp3_, "add-item", (GObject*) transfer);
#line 442 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (transfer);
#line 3310 "transfers.c"
}


static gboolean transfers_manager_notification_timeout_triggered (TransfersManager* self) {
	gboolean result = FALSE;
	GList* _tmp0_;
	guint _tmp1_;
#line 450 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 451 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->notification_timeout = (guint) 0;
#line 452 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->notifications;
#line 452 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = g_list_length (_tmp0_);
#line 452 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp1_ > ((guint) 0)) {
#line 3328 "transfers.c"
		gchar* filename = NULL;
		GList* _tmp2_;
		gconstpointer _tmp3_;
		gchar* _tmp4_;
		gchar* msg = NULL;
		GList* _tmp5_;
		guint _tmp6_;
		MidoriApp* _tmp13_;
		const gchar* _tmp14_;
#line 453 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp2_ = self->notifications;
#line 453 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp3_ = g_list_nth_data (_tmp2_, (guint) 0);
#line 453 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp4_ = g_strdup ((const gchar*) _tmp3_);
#line 453 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		filename = _tmp4_;
#line 455 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp5_ = self->notifications;
#line 455 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp6_ = g_list_length (_tmp5_);
#line 455 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		if (_tmp6_ == ((guint) 1)) {
#line 3352 "transfers.c"
			const gchar* _tmp7_;
			gchar* _tmp8_;
#line 456 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp7_ = filename;
#line 456 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp8_ = g_strdup_printf (_ ("The file '<b>%s</b>' has been downloaded."), _tmp7_);
#line 456 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_g_free0 (msg);
#line 456 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			msg = _tmp8_;
#line 3363 "transfers.c"
		} else {
			const gchar* _tmp9_;
			GList* _tmp10_;
			guint _tmp11_;
			gchar* _tmp12_;
#line 458 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp9_ = filename;
#line 458 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp10_ = self->notifications;
#line 458 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp11_ = g_list_length (_tmp10_);
#line 458 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp12_ = g_strdup_printf (_ ("'<b>%s</b>' and %d other files have been downloaded."), _tmp9_, (gint) _tmp11_);
#line 458 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_g_free0 (msg);
#line 458 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			msg = _tmp12_;
#line 3381 "transfers.c"
		}
#line 459 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp13_ = midori_extension_get_app ((MidoriExtension*) self);
#line 459 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp14_ = msg;
#line 459 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		midori_app_send_notification (_tmp13_, _ ("Transfer completed"), _tmp14_);
#line 460 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		__g_list_free__g_free0_0 (self->notifications);
#line 460 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		self->notifications = NULL;
#line 452 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_free0 (msg);
#line 452 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_free0 (filename);
#line 3397 "transfers.c"
	}
#line 462 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = FALSE;
#line 462 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 3403 "transfers.c"
}


static gboolean _transfers_manager_notification_timeout_triggered_gsource_func (gpointer self) {
	gboolean result;
	result = transfers_manager_notification_timeout_triggered ((TransfersManager*) self);
#line 490 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 3412 "transfers.c"
}


static void transfers_manager_transfer_changed (TransfersManager* self, TransfersTransfer* transfer) {
	TransfersTransfer* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	GError * _inner_error_ = NULL;
#line 465 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 465 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (transfer != NULL);
#line 466 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = transfer;
#line 466 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = transfers_transfer_get_succeeded (_tmp0_);
#line 466 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = _tmp1_;
#line 466 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp2_) {
#line 3433 "transfers.c"
		TransfersTransfer* _tmp3_;
		gint _tmp4_;
		gint _tmp5_;
		gchar* uri = NULL;
		TransfersTransfer* _tmp15_;
		const gchar* _tmp16_;
		const gchar* _tmp17_;
		gchar* _tmp18_;
		gchar* filename = NULL;
		const gchar* _tmp19_;
		gchar* _tmp20_;
		KatzeItem* item = NULL;
		KatzeItem* _tmp21_;
		KatzeItem* _tmp22_;
		const gchar* _tmp23_;
		KatzeItem* _tmp24_;
		const gchar* _tmp25_;
		KatzeItem* _tmp26_;
		TransfersTransfer* _tmp27_;
		WebKitDownload* _tmp28_;
		gboolean _tmp29_;
		const gchar* _tmp32_;
		gchar* _tmp33_;
		guint _tmp34_;
#line 468 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp3_ = transfer;
#line 468 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp4_ = transfers_transfer_get_action (_tmp3_);
#line 468 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp5_ = _tmp4_;
#line 468 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		if (_tmp5_ == ((gint) MIDORI_DOWNLOAD_OPEN)) {
#line 3466 "transfers.c"
			{
				gboolean _tmp6_ = FALSE;
				TransfersTransfer* _tmp7_;
				WebKitDownload* _tmp8_;
				GList* _tmp9_;
				gconstpointer _tmp10_;
				gboolean _tmp11_;
#line 470 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp7_ = transfer;
#line 470 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp8_ = _tmp7_->download;
#line 470 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp9_ = self->widgets;
#line 470 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp10_ = g_list_nth_data (_tmp9_, (guint) 0);
#line 470 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp11_ = midori_download_action_clear (_tmp8_, (GtkWidget*) _tmp10_, &_inner_error_);
#line 470 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp6_ = _tmp11_;
#line 470 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3488 "transfers.c"
					goto __catch3_g_error;
				}
#line 470 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				if (_tmp6_) {
#line 3493 "transfers.c"
					TransfersTransfer* _tmp12_;
#line 471 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					_tmp12_ = transfer;
#line 471 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
					g_signal_emit (_tmp12_, transfers_transfer_signals[TRANSFERS_TRANSFER_REMOVE_SIGNAL], 0);
#line 3499 "transfers.c"
				}
			}
			goto __finally3;
			__catch3_g_error:
			{
				GError* _error_ = NULL;
				GError* _tmp13_;
				const gchar* _tmp14_;
#line 469 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_error_ = _inner_error_;
#line 469 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_inner_error_ = NULL;
#line 474 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp13_ = _error_;
#line 474 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp14_ = _tmp13_->message;
#line 474 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				g_warning (_ ("Failed to open download: %s"), _tmp14_);
#line 469 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_g_error_free0 (_error_);
#line 3520 "transfers.c"
			}
			__finally3:
#line 469 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 469 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 469 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				g_clear_error (&_inner_error_);
#line 469 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				return;
#line 3531 "transfers.c"
			}
		}
#line 478 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp15_ = transfer;
#line 478 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp16_ = transfers_transfer_get_destination (_tmp15_);
#line 478 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp17_ = _tmp16_;
#line 478 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp18_ = g_strdup (_tmp17_);
#line 478 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		uri = _tmp18_;
#line 479 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp19_ = uri;
#line 479 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp20_ = midori_download_get_basename_for_display (_tmp19_);
#line 479 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		filename = _tmp20_;
#line 480 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp21_ = katze_item_new ();
#line 480 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		item = _tmp21_;
#line 481 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp22_ = item;
#line 481 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp23_ = uri;
#line 481 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		katze_item_set_uri (_tmp22_, _tmp23_);
#line 482 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp24_ = item;
#line 482 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp25_ = filename;
#line 482 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		katze_item_set_name (_tmp24_, _tmp25_);
#line 483 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp26_ = item;
#line 483 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		midori_browser_update_history (_tmp26_, "download", "create");
#line 484 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp27_ = transfer;
#line 484 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp28_ = _tmp27_->download;
#line 484 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp29_ = midori_download_has_wrong_checksum (_tmp28_);
#line 484 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		if (!_tmp29_) {
#line 3578 "transfers.c"
			GtkRecentManager* _tmp30_;
			const gchar* _tmp31_;
#line 485 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp30_ = gtk_recent_manager_get_default ();
#line 485 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp31_ = uri;
#line 485 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			gtk_recent_manager_add_item (_tmp30_, _tmp31_);
#line 3587 "transfers.c"
		}
#line 487 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp32_ = filename;
#line 487 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp33_ = g_strdup (_tmp32_);
#line 487 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		self->notifications = g_list_append (self->notifications, _tmp33_);
#line 488 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp34_ = self->notification_timeout;
#line 488 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		if (_tmp34_ == ((guint) 0)) {
#line 3599 "transfers.c"
			guint _tmp35_;
#line 489 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			transfers_manager_notification_timeout_triggered (self);
#line 490 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp35_ = midori_timeout_add_seconds ((guint) 60, _transfers_manager_notification_timeout_triggered_gsource_func, g_object_ref (self), g_object_unref);
#line 490 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			self->notification_timeout = _tmp35_;
#line 3607 "transfers.c"
		}
#line 466 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (item);
#line 466 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_free0 (filename);
#line 466 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_free0 (uri);
#line 3615 "transfers.c"
	}
}


static void transfers_manager_transfer_remove (TransfersManager* self, TransfersTransfer* transfer) {
	KatzeArray* _tmp0_;
	TransfersTransfer* _tmp1_;
#line 495 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 495 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (transfer != NULL);
#line 496 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->array;
#line 496 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = transfer;
#line 496 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_emit_by_name (_tmp0_, "remove-item", (GObject*) _tmp1_);
#line 3633 "transfers.c"
}


static void transfers_manager_transfer_removed (TransfersManager* self, GObject* item) {
	TransfersTransfer* transfer = NULL;
	GObject* _tmp0_;
	TransfersTransfer* _tmp1_;
#line 499 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 499 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (item != NULL);
#line 500 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = item;
#line 500 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TRANSFERS_TYPE_TRANSFER) ? ((TransfersTransfer*) _tmp0_) : NULL);
#line 500 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfer = _tmp1_;
#line 501 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_emit (transfer, transfers_transfer_signals[TRANSFERS_TRANSFER_REMOVED_SIGNAL], 0);
#line 499 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (transfer);
#line 3655 "transfers.c"
}


static gboolean transfers_manager_browser_closed (TransfersManager* self, GtkWidget* widget, GdkEvent* event) {
	gboolean result = FALSE;
	MidoriBrowser* browser = NULL;
	GtkWidget* _tmp0_;
	MidoriBrowser* _tmp1_;
	KatzeArray* _tmp2_;
	gboolean _tmp3_;
#line 507 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 507 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (widget != NULL, FALSE);
#line 507 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 509 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = widget;
#line 509 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, MIDORI_TYPE_BROWSER) ? ((MidoriBrowser*) _tmp0_) : NULL);
#line 509 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	browser = _tmp1_;
#line 510 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = self->array;
#line 510 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp3_ = transfers_pending_transfers (_tmp2_);
#line 510 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	if (_tmp3_) {
#line 3684 "transfers.c"
		GtkMessageDialog* dialog = NULL;
		MidoriBrowser* _tmp4_;
		GtkMessageDialog* _tmp5_;
		GtkMessageDialog* _tmp6_;
		GtkMessageDialog* _tmp7_;
		GtkMessageDialog* _tmp8_;
		gboolean cancel = FALSE;
		GtkMessageDialog* _tmp9_;
		gint _tmp10_;
		GtkMessageDialog* _tmp11_;
#line 511 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp4_ = browser;
#line 511 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp5_ = (GtkMessageDialog*) gtk_message_dialog_new ((GtkWindow*) _tmp4_, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE, "%s", _ ("Some files are being downloaded"));
#line 511 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		g_object_ref_sink (_tmp5_);
#line 511 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		dialog = _tmp5_;
#line 516 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp6_ = dialog;
#line 516 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_window_set_title ((GtkWindow*) _tmp6_, _ ("Some files are being downloaded"));
#line 517 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp7_ = dialog;
#line 517 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_dialog_add_buttons ((GtkDialog*) _tmp7_, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, _ ("_Quit Midori"), GTK_RESPONSE_ACCEPT, NULL);
#line 519 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp8_ = dialog;
#line 519 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_message_dialog_format_secondary_text (_tmp8_, "%s", _ ("The transfers will be cancelled if Midori quits."));
#line 521 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp9_ = dialog;
#line 521 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp10_ = gtk_dialog_run ((GtkDialog*) _tmp9_);
#line 521 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		cancel = _tmp10_ != ((gint) GTK_RESPONSE_ACCEPT);
#line 522 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_tmp11_ = dialog;
#line 522 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		gtk_object_destroy ((GtkObject*) _tmp11_);
#line 523 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		result = cancel;
#line 523 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (dialog);
#line 523 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_object_unref0 (browser);
#line 523 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		return result;
#line 3733 "transfers.c"
	}
#line 525 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = FALSE;
#line 525 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (browser);
#line 525 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 3741 "transfers.c"
}


static void _transfers_manager_download_added_midori_browser_add_download (MidoriBrowser* _sender, WebKitDownload* download, gpointer self) {
#line 542 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_manager_download_added ((TransfersManager*) self, download);
#line 3748 "transfers.c"
}


static gboolean _transfers_manager_browser_closed_gtk_widget_delete_event (GtkWidget* _sender, GdkEvent* event, gpointer self) {
	gboolean result;
	result = transfers_manager_browser_closed ((TransfersManager*) self, _sender, event);
#line 543 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 3757 "transfers.c"
}


static void transfers_manager_browser_added (TransfersManager* self, MidoriBrowser* browser) {
	TransfersSidebar* viewable = NULL;
	KatzeArray* _tmp0_;
	TransfersSidebar* _tmp1_;
	MidoriBrowser* _tmp2_;
	MidoriPanel* _tmp3_;
	MidoriPanel* _tmp4_;
	MidoriPanel* _tmp5_;
	GtkWidget* _tmp6_;
	TransfersToolbar* toolbar = NULL;
	KatzeArray* _tmp7_;
	TransfersToolbar* _tmp8_;
	MidoriBrowser* _tmp9_;
	GtkStatusbar* _tmp10_;
	GtkStatusbar* _tmp11_;
	GtkStatusbar* _tmp12_;
	GtkWidget* _tmp13_;
	MidoriBrowser* _tmp14_;
	MidoriBrowser* _tmp15_;
#line 528 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 528 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (browser != NULL);
#line 529 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = self->array;
#line 529 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = transfers_sidebar_new (_tmp0_);
#line 529 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_ref_sink (_tmp1_);
#line 529 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	viewable = _tmp1_;
#line 530 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_widget_show ((GtkWidget*) viewable);
#line 531 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = browser;
#line 531 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_get (_tmp2_, "panel", &_tmp3_, NULL);
#line 531 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = _tmp3_;
#line 531 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp5_ = _tmp4_;
#line 531 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	midori_panel_append_page (_tmp5_, (MidoriViewable*) viewable);
#line 531 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (_tmp5_);
#line 532 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp6_ = _g_object_ref0 ((GtkWidget*) viewable);
#line 532 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->widgets = g_list_append (self->widgets, _tmp6_);
#line 533 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp7_ = self->array;
#line 533 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp8_ = transfers_toolbar_new (_tmp7_);
#line 533 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_ref_sink (_tmp8_);
#line 533 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	toolbar = _tmp8_;
#line 537 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp9_ = browser;
#line 537 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_object_get (_tmp9_, "statusbar", &_tmp10_, NULL);
#line 537 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp11_ = _tmp10_;
#line 537 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp12_ = _tmp11_;
#line 537 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	gtk_box_pack_start ((GtkBox*) _tmp12_, (GtkWidget*) toolbar, FALSE, FALSE, (guint) 0);
#line 537 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (_tmp12_);
#line 539 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp13_ = _g_object_ref0 ((GtkWidget*) toolbar);
#line 539 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->widgets = g_list_append (self->widgets, _tmp13_);
#line 542 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp14_ = browser;
#line 542 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object (_tmp14_, "add-download", (GCallback) _transfers_manager_download_added_midori_browser_add_download, self, 0);
#line 543 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp15_ = browser;
#line 543 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object ((GtkWidget*) _tmp15_, "delete-event", (GCallback) _transfers_manager_browser_closed_gtk_widget_delete_event, self, 0);
#line 528 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (toolbar);
#line 528 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (viewable);
#line 3846 "transfers.c"
}


static void _transfers_manager_browser_added_midori_app_add_browser (MidoriApp* _sender, MidoriBrowser* browser, gpointer self) {
#line 553 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_manager_browser_added ((TransfersManager*) self, browser);
#line 3853 "transfers.c"
}


static void transfers_manager_activated (TransfersManager* self, MidoriApp* app) {
	KatzeArray* _tmp0_;
	MidoriApp* _tmp1_;
	GList* _tmp2_;
	MidoriApp* _tmp4_;
#line 546 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 546 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (app != NULL);
#line 547 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = katze_array_new (TRANSFERS_TYPE_TRANSFER);
#line 547 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->array);
#line 547 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->array = _tmp0_;
#line 548 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	__g_list_free__g_object_unref0_0 (self->widgets);
#line 548 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->widgets = NULL;
#line 549 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	__g_list_free__g_free0_0 (self->notifications);
#line 549 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->notifications = NULL;
#line 550 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self->notification_timeout = (guint) 0;
#line 551 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = app;
#line 551 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = midori_app_get_browsers (_tmp1_);
#line 3886 "transfers.c"
	{
		GList* browser_collection = NULL;
		GList* browser_it = NULL;
#line 551 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		browser_collection = _tmp2_;
#line 551 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		for (browser_it = browser_collection; browser_it != NULL; browser_it = browser_it->next) {
#line 3894 "transfers.c"
			MidoriBrowser* browser = NULL;
#line 551 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			browser = (MidoriBrowser*) browser_it->data;
#line 3898 "transfers.c"
			{
				MidoriBrowser* _tmp3_;
#line 552 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp3_ = browser;
#line 552 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				transfers_manager_browser_added (self, _tmp3_);
#line 3905 "transfers.c"
			}
		}
#line 551 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_list_free0 (browser_collection);
#line 3910 "transfers.c"
	}
#line 553 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = app;
#line 553 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object (_tmp4_, "add-browser", (GCallback) _transfers_manager_browser_added_midori_app_add_browser, self, 0);
#line 3916 "transfers.c"
}


static void transfers_manager_deactivated (TransfersManager* self) {
	MidoriApp* app = NULL;
	MidoriApp* _tmp0_;
	MidoriApp* _tmp1_;
	MidoriApp* _tmp2_;
	guint _tmp3_;
	MidoriApp* _tmp4_;
	GList* _tmp5_;
	GList* _tmp10_;
	KatzeArray* _tmp13_;
	guint _tmp14_;
#line 556 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_return_if_fail (self != NULL);
#line 557 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = midori_extension_get_app ((MidoriExtension*) self);
#line 557 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 557 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	app = _tmp1_;
#line 558 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp2_ = app;
#line 558 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_parse_name ("add-browser", MIDORI_TYPE_APP, &_tmp3_, NULL, FALSE);
#line 558 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _transfers_manager_browser_added_midori_app_add_browser, self);
#line 559 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp4_ = app;
#line 559 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp5_ = midori_app_get_browsers (_tmp4_);
#line 3949 "transfers.c"
	{
		GList* browser_collection = NULL;
		GList* browser_it = NULL;
#line 559 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		browser_collection = _tmp5_;
#line 559 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		for (browser_it = browser_collection; browser_it != NULL; browser_it = browser_it->next) {
#line 3957 "transfers.c"
			MidoriBrowser* browser = NULL;
#line 559 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			browser = (MidoriBrowser*) browser_it->data;
#line 3961 "transfers.c"
			{
				MidoriBrowser* _tmp6_;
				guint _tmp7_;
				MidoriBrowser* _tmp8_;
				guint _tmp9_;
#line 560 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp6_ = browser;
#line 560 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				g_signal_parse_name ("add-download", MIDORI_TYPE_BROWSER, &_tmp7_, NULL, FALSE);
#line 560 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				g_signal_handlers_disconnect_matched (_tmp6_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp7_, 0, NULL, (GCallback) _transfers_manager_download_added_midori_browser_add_download, self);
#line 561 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp8_ = browser;
#line 561 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				g_signal_parse_name ("delete-event", GTK_TYPE_WIDGET, &_tmp9_, NULL, FALSE);
#line 561 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				g_signal_handlers_disconnect_matched ((GtkWidget*) _tmp8_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp9_, 0, NULL, (GCallback) _transfers_manager_browser_closed_gtk_widget_delete_event, self);
#line 3979 "transfers.c"
			}
		}
#line 559 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		_g_list_free0 (browser_collection);
#line 3984 "transfers.c"
	}
#line 563 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp10_ = self->widgets;
#line 3988 "transfers.c"
	{
		GList* widget_collection = NULL;
		GList* widget_it = NULL;
#line 563 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		widget_collection = _tmp10_;
#line 563 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
		for (widget_it = widget_collection; widget_it != NULL; widget_it = widget_it->next) {
#line 3996 "transfers.c"
			GtkWidget* _tmp11_;
			GtkWidget* widget = NULL;
#line 563 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			_tmp11_ = _g_object_ref0 ((GtkWidget*) widget_it->data);
#line 563 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
			widget = _tmp11_;
#line 4003 "transfers.c"
			{
				GtkWidget* _tmp12_;
#line 564 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_tmp12_ = widget;
#line 564 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				gtk_object_destroy ((GtkObject*) _tmp12_);
#line 563 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
				_g_object_unref0 (widget);
#line 4012 "transfers.c"
			}
		}
	}
#line 565 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp13_ = self->array;
#line 565 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_parse_name ("remove-item", KATZE_TYPE_ARRAY, &_tmp14_, NULL, FALSE);
#line 565 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_handlers_disconnect_matched (_tmp13_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp14_, 0, NULL, (GCallback) _transfers_manager_transfer_removed_katze_array_remove_item, self);
#line 556 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (app);
#line 4024 "transfers.c"
}


static void _transfers_manager_activated_midori_extension_activate (MidoriExtension* _sender, MidoriApp* app, gpointer self) {
#line 574 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_manager_activated ((TransfersManager*) self, app);
#line 4031 "transfers.c"
}


static void _transfers_manager_deactivated_midori_extension_deactivate (MidoriExtension* _sender, gpointer self) {
#line 575 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_manager_deactivated ((TransfersManager*) self);
#line 4038 "transfers.c"
}


TransfersManager* transfers_manager_construct (GType object_type) {
	TransfersManager * self = NULL;
#line 569 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = (TransfersManager*) g_object_new (object_type, "name", _ ("Transfer Manager"), "description", _ ("View downloaded files"), "version", "0.1" MIDORI_VERSION_SUFFIX, "authors", "Christian Dywan <christian@twotoasts.de>", NULL);
#line 574 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object ((MidoriExtension*) self, "activate", (GCallback) _transfers_manager_activated_midori_extension_activate, self, 0);
#line 575 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	g_signal_connect_object ((MidoriExtension*) self, "deactivate", (GCallback) _transfers_manager_deactivated_midori_extension_deactivate, self, 0);
#line 568 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return self;
#line 4052 "transfers.c"
}


TransfersManager* transfers_manager_new (void) {
#line 568 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return transfers_manager_construct (TRANSFERS_TYPE_MANAGER);
#line 4059 "transfers.c"
}


static void transfers_manager_class_init (TransfersManagerClass * klass) {
#line 436 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	transfers_manager_parent_class = g_type_class_peek_parent (klass);
#line 436 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	G_OBJECT_CLASS (klass)->finalize = transfers_manager_finalize;
#line 4068 "transfers.c"
}


static void transfers_manager_instance_init (TransfersManager * self) {
}


static void transfers_manager_finalize (GObject * obj) {
	TransfersManager * self;
#line 436 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TRANSFERS_TYPE_MANAGER, TransfersManager);
#line 437 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_g_object_unref0 (self->array);
#line 438 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	__g_list_free__g_object_unref0_0 (self->widgets);
#line 439 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	__g_list_free__g_free0_0 (self->notifications);
#line 436 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	G_OBJECT_CLASS (transfers_manager_parent_class)->finalize (obj);
#line 4088 "transfers.c"
}


GType transfers_manager_get_type (void) {
	static volatile gsize transfers_manager_type_id__volatile = 0;
	if (g_once_init_enter (&transfers_manager_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TransfersManagerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) transfers_manager_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TransfersManager), 0, (GInstanceInitFunc) transfers_manager_instance_init, NULL };
		GType transfers_manager_type_id;
		transfers_manager_type_id = g_type_register_static (MIDORI_TYPE_EXTENSION, "TransfersManager", &g_define_type_info, 0);
		g_once_init_leave (&transfers_manager_type_id__volatile, transfers_manager_type_id);
	}
	return transfers_manager_type_id__volatile;
}


MidoriExtension* extension_init (void) {
	MidoriExtension* result = NULL;
	TransfersManager* _tmp0_;
#line 581 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	_tmp0_ = transfers_manager_new ();
#line 581 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	result = (MidoriExtension*) _tmp0_;
#line 581 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/transfers.vala"
	return result;
#line 4113 "transfers.c"
}



